<?php

namespace Teknisa\TCO\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;

class Tco01200CardapioDaProposta extends \Teknisa\GER\Controllers\TeknisaCrud {
    
    protected $crudService;
    protected $environment;
    protected $entityManager;
    protected $dataSourceManager;
    protected $connection;
    protected $message;
    protected $Tco01200CardapioDaPropostaService;
    protected $newCode;
    protected $dataSourceToSave = "tco01200_config_elab_card";
    protected $dataSourceToSaveProducts = "recepratcardtrab";
    protected $tcoUtil;
    protected $lista;
    protected $TcoDadosPratoService;

    public function __construct($crudService, $parameterBag, $environment, $entityManager, $Tco01200CardapioDaPropostaService, $dataSourceManager, $newCode, $connection, $message, $tcoUtil, $lista, $TcoDadosPratoService) {
        $this->crudService                          = $crudService;
        $this->environment                          = $environment;
        $this->entityManager                        = $entityManager;
        $this->Tco01200CardapioDaPropostaService    = $Tco01200CardapioDaPropostaService;
        $this->dataSourceManager                    = $dataSourceManager;
        $this->newCode                              = $newCode;
        $this->connection                           = $connection;
        $this->message                              = $message;
        $this->tcoUtil                              = $tcoUtil;
        $this->lista                                = $lista;
        $this->TcoDadosPratoService                 = $TcoDadosPratoService;
    }
    
    public function getServPropCom(DTO\Request\Filter $request, DTO\Response $response){
        try {
            $filter = null;
            $filterCriteria = $request->getFilterCriteria();
            $conditions = $filterCriteria->getConditions();
            if(!empty($conditions)){
                $filter = $this->buildFilterParams($conditions);
            }
            $dataSet = $this->Tco01200CardapioDaPropostaService->getServPropCom($filter, $conditions);
            $response->addDataSet(new DataSet('tco01200_cardapio_da_proposta', $dataSet));
        } catch (\Exception $e){
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }
    
    private function buildFilterParams($filter){
        $params = array();
        $multipleSelected = array('CDPROSPECT', 'CDPADRAOQUALIDADE', 'CDTIPOPUBLICO', 'CDCLIENTE', 'CDSERVICOPROPOSTA', 'CDOPERADOR');
        foreach ($filter as $key => &$value) {
            if(in_array($value['columnName'], $multipleSelected)){
                $value['value'] = $this->concatValues($value['value']);
            }    
            if(is_string($value['value'])){
                $value['value'] = preg_replace("/[%]/", "", $value['value']);
            }
            if(in_array($value['columnName'], $multipleSelected)){
                $value['value'] = $this->lista->criarListaValores($value['value']);
            }
            
            $params[$value['columnName']] = $value['value']; 
        }
        $params['DTINI'] = $params['DTLANCAMENTO'][0];
        $params['DTFIN'] = $params['DTLANCAMENTO'][1];
        return $params;
    }
    
    private function concatValues($values){
        if(is_array($values)) $object = $values;
        else $object = explode(",",$values);
        return implode('_', $object);
    }
    
     public function saveConfigTipoPrato(DTO\Request $request, DTO\Response $response) {
        try {
            $dataSet = $request->getDataSet();
            $dataSet = $this->defineDefaultValues($dataSet);
            $dataSet = $this->Tco01200CardapioDaPropostaService->generateNewOrder($dataSet);
            $dataSet->setDataSourceName($this->dataSourceToSave);
            $persistedRows = $this->dataSourceManager->persist($dataSet);
            $response->addDataSet(new DataSet($this->dataSourceToSave, $persistedRows));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }
    
     public function defineDefaultValues($dataSet){
        $data = $dataSet->getRows()[0];
        $data["__is_new"] = true;
        $data["NRORG"] = $this->environment->getNrOrg();
        $dataSet->getRows()[0]["NRCONFIGCARDBASE"] = null;
        $dataSet->getRows()[0]["NRCONFIGCARDTRAB"] = $this->newCode->getCodeByTableName('CONFIGCARDTRAB', $dataSet->getRows()[0]["NRORG"]);
        if(empty($data["DSCOMPLEMENTO"])) $data["DSCOMPLEMENTO"] = "";
        if(empty($data["IDTEMPERATURA"])) $data["IDTEMPERATURA"] = "";
        return $dataSet;
    }
    
    public function deleteConfigTipoPrato(DTO\Request $request, DTO\Response $response){
        try {
            $dataSet = $request->getDataSet();
            $valid = $this->Tco01200CardapioDaPropostaService->hasPrato($dataSet);
            if($valid){
                $rows = $this->crudService->getRowsToDelete($request, 'tco01200_config_elab_card');
                $dataSet = new DataSet("tco01200_config_elab_card", $rows);
        		$this->crudService->delete($response, $dataSet);
            }else{
                throw new \Exception("Operação Bloqueada. Coluna possui pratos relacionados.",400);
            }
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function getDadosPrato(DTO\Request $request, DTO\Response $response){
        try{
            $row = $request->getRow();
            $row['CDNVPRATO'] = $this->Tco01200CardapioDaPropostaService->getNivelPrato();
            $row['CDFILIAL'] = $this->Tco01200CardapioDaPropostaService->getFilialParamTco();
            $persistedRows = $this->Tco01200CardapioDaPropostaService->getDadosPrato($row);
            $response->addDataSet(new DataSet('tco_01205_pratos', $persistedRows));
        }catch(\Exception $e){
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function addOrUpdatePrato(DTO\Request $request, DTO\Response $response){
        try {
            $this->dataSourceName = 'compcardtrab';
            $row = $request->getDataSet()->getRows()[0];
            if(empty($row["NRCOMPCARDTRAB"])){
                 $row["NRCOMPCARDTRAB"] = $this->newCode->getCodeByTableName('COMPCARDTRAB', $this->environment->getNrOrgTrab());
            }
            $row["__is_new"] = $this->tcoUtil->verifyCompCardTrabIsNew($row);
            $rowCardTrab = $this->TcoDadosPratoService->produtosReceita($row);
            $this->saveReceCardTrab($rowCardTrab, $row);
            $rows = $this->crudService->getRowsToSave($request, $this->dataSourceName);
            $this->crudService->save($this->dataSourceName, $rows);
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }
    
    private function saveReceCardTrab($rowCardTrab, $row){
        foreach($rowCardTrab as $key => &$product){
            
            if(empty($product["NRRECEPRATCARDTRAB"])){
                $product["NRRECEPRATCARDTRAB"] = $this->newCode->getCodeByTableName('RECEPRATCARDTRAB', $this->environment->getNrOrgTrab());
            }
            $rowProduct = $this->buildParamsProducts($product, $row['NRCARDAPIOTRAB']);
            $rowProduct[0]["__is_new"] = $this->Tco01200CardapioDaPropostaService->verifyReceCardTrabIsNew($rowProduct[0]);
            $dataSet = new DataSet("recepratcardtrab", $rowProduct);
            $request = new DTO\Request\DataSet($dataSet, "", "", "");
            $rowProduct = $this->crudService->getRowsToSave($request, 'recepratcardtrab');
            $this->crudService->save('recepratcardtrab', $rowProduct); 
        }
    }
    
     private function buildParamsProducts($product, $nrcardapiotrab){
        return array(
            array(
                "NRRECEPRATCARDTRAB" => $product["NRRECEPRATCARDTRAB"],
                "NRCARDAPIOTRAB" => $nrcardapiotrab,
                "CDFILAUXPRAT" => $product["CDFILAUXPRAT"],
                "CDPRATO" => $product["CDPRATO"],
                "CDPRODUTO" => $product["CDPRODUTO"],
                "QTPRODRECCARDTRAB" => $product["QTPRODUTO"],
                "VRPEFATCOCCARDTRAB" => $product["VRGANHOCOCCAO"],
                "VRPEFATCORCARDTRAB" => $product["VRPERDALIMPEZA"],
                "SGUNIDADE" => $product["SGUNIDADE"],
                "QTBRUTACARDTRABUNR" => $product["QTDBRUTA"],
                "NRORG" => $this->environment->getNrOrg(),
                "IDPRODBASECARDTRAB" => $product["BASE"],
                "IDQTDEFIXCARDTRAB" => $product["QTFIX"],
                "IDINCLUIDO" => 'N'
            )
        );
    }
    
    public function removePrato(DTO\Request $request, DTO\Response $response){
        try {
            $dataSet = $request->getDataSet();
            $rows = $this->crudService->getRowsToDelete($request, 'compcardtrab');
            $dataSet = new DataSet("compcardtrab", $rows);
            if(!empty($dataSet->getRows()[0]['NRCOMPCARDTRAB'])){
    		    $this->crudService->delete($response, $dataSet);
		    }else{
		        throw new \Exception("Operação Bloqueada. Não há prato para ser deletado.",400);
		    }
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function confirmReview(DTO\Request $request, DTO\Response $response){
        try {
            $dataSet = $request->getDataSet();
            $rows = $dataSet->getRows();
            $nrorg = $this->environment->getNrOrg();
            $invalidRows = $this->Tco01200CardapioDaPropostaService->verifyIsNewProduct($rows);
            if(empty($invalidRows)){
                foreach($rows as $key => &$row){
                    if($row["__is_new"]){
                        $rows[$key]["NRRECEPRATCARDTRAB"] = $this->newCode->getCodeByTableName('RECEPRATCARDTRAB', $nrorg);
                    }
                    $rows[$key]["QTPRODRECCARDTRAB"] = (float) $rows[$key]["QTPRODRECCARDTRAB"];
                    $rows[$key]["QTBRUTACARDTRABUNR"] = (float) $rows[$key]["QTBRUTACARDTRABUNR"];
                    $rows[$key]["VRPEFATCOCCARDTRAB"] = (float) $rows[$key]["VRPEFATCOCCARDTRAB"];
                    $rows[$key]["VRPEFATCORCARDTRAB"] = (float) $rows[$key]["VRPEFATCORCARDTRAB"];
                }
                $dataSet = $this->crudService->getRowsToSave($request, $this->dataSourceToSaveProducts);
                $this->crudService->save($this->dataSourceToSaveProducts, $dataSet);
                $response->addDataSet(new DataSet('products', $dataSet));
            }else{
                throw new \Exception("invalidRows", 400);
            }
        } catch (\Exception $e) {
            if($e->getMessage() == "invalidRows")
                $response->addDataSet(new DataSource\DataSet("invalidRows", $invalidRows));
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function getAnaliseCusto(DTO\Request $request, DTO\Response $response){
        $filter = $request->getFilterCriteria();
        $conditions = $filter->getConditions();
        $dataSet = $this->crudService->getFilteredDataSet('tco01200_analise_custo', $conditions);
        $rows = $this->calculaAnaliseDeCusto($dataSet);
        $dataSet = new DataSet('tco01200_analise_custo', $rows);
        $response->addDataSet($dataSet);
    }
    
    private function calculaAnaliseDeCusto($dataSet){
        $dataSetAnalise = $dataSet->getRows();
        $custoacumulado = 0;
        $comensaisacumulados = 0;
        
        foreach ($dataSetAnalise as $key => &$data) {
            if($data['VRCUSTO'] > 0 ){
                $dataSetAnalise[$key]["CUSTOPERCAPITA"] = $data["VRCUSTO"]/$data["QTCOMENSAIS"];
                $custoacumulado += $data["VRCUSTO"];
                $dataSetAnalise[$key]["CUSTOACUMULADO"] = $custoacumulado;
                $comensaisacumulados += $data["QTCOMENSAIS"];
                $dataSetAnalise[$key]["COMENSAISACUMULADOS"] += $comensaisacumulados;
                $dataSetAnalise[$key]["CUSTOPERCMEDIO"] = $custoacumulado/$comensaisacumulados;
            } else if($key - 1 >= 0){
                $dataSetAnalise[$key]["CUSTOACUMULADO"] = $dataSetAnalise[$key-1]["CUSTOACUMULADO"];
                $dataSetAnalise[$key]["COMENSAISACUMULADOS"] = $dataSetAnalise[$key-1]["COMENSAISACUMULADOS"];
                $dataSetAnalise[$key]["CUSTOPERCMEDIO"] = $dataSetAnalise[$key-1]["CUSTOPERCMEDIO"];
            }
        }
          
        return $dataSetAnalise;
    }
    
    public function confirmResponsible(DTO\Request $request, DTO\Response $response){
        try {
            $rows = $request->getDataSet()->getRows()[0];
            if(empty($rows["NRSERVICOPROPCOM"])) throw new \Exception("Operação inválida! Não existe serviço de proposta comercial.", 400);
            $operador = $this->Tco01200CardapioDaPropostaService->updateResponsibleOperator($rows);
            $response->addDataSet(new DataSet('confirmResponsible', array($operador)));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function finish(DTO\Request $request, DTO\Response $response){
        try {
            $row = $request->getDataSet()->getRows()[0];
            if(!empty($row['P_NRCARDAPIOTRAB'])){
			    $result = $this->validCardTrab($row, $response);
			    if(!empty($result['P_LISTAERROS'])){
                    $struct = array(
                        'TIPO' => 'LISTA',
                        'CDFILIAL' => $this->environment->getCdFilial(),
                        'NRLISTA'  => $result['P_LISTAERROS']
                    );  
                    $response->addDataSet(new DataSet("ERROR", $this->message->convertMessage($struct)));
                    return;
                }
            }
		    $this->solAltServPropCom($row, $response);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    private function validCardTrab ($row, DTO\Response $response){
        
		$procedure = new StoredProcedure($this->connection, 'VALIDA_CARDTRAB');
		$procedure->addParam(new Param('P_NRCARDAPIOTRAB',  Param::PARAM_INPUT,  $row['P_NRCARDAPIOTRAB'], Param::PARAM_TYPE_INT));
	    $procedure->addParam(new Param('P_NRORG',           Param::PARAM_INPUT,  $this->environment->getNrorgTrab(),          Param::PARAM_TYPE_INT));
	    $procedure->addParam(new Param('P_CDOPERADOR',      Param::PARAM_INPUT,  $this->environment->getCdoperador(),     Param::PARAM_TYPE_STR));
		$procedure->addParam(new Param('P_CDFILIALLOGADA',  Param::PARAM_INPUT,  $this->environment->getCdFilial(), Param::PARAM_TYPE_STR));
		$procedure->addParam(new Param('P_LISTAERROS',      Param::PARAM_OUTPUT, null,                     Param::PARAM_TYPE_STR,20));

		$result = $procedure->execute();
		return $result;
    }
    
    private function solAltServPropCom ($row, DTO\Response $response){
        try {
            //$row["P_TXHISTORICO"] = $this->Tco01200CardapioDaPropostaService->buildScope($row);
            $row["P_TXHISTORICO"] = null;
			$procedure = new StoredProcedure($this->connection, 'SOL_ALT_SERVPROPCOM');
			$procedure->addParam(new Param('P_NRSERVICOPROPCOM', Param::PARAM_INPUT, $row['P_NRSERVICOPROPCOM'], Param::PARAM_TYPE_INT));
			$procedure->addParam(new Param('P_IDORIGEM', Param::PARAM_INPUT, $row['P_IDORIGEM'], Param::PARAM_TYPE_STR));
			$procedure->addParam(new Param('P_IDDESTINO', Param::PARAM_INPUT, $row['P_IDDESTINO'], Param::PARAM_TYPE_STR));
			$procedure->addParam(new Param('P_IDMOTIVO', Param::PARAM_INPUT, $row['P_IDMOTIVO'], Param::PARAM_TYPE_STR));
			$procedure->addParam(new Param('P_DSOBSERVACAO', Param::PARAM_INPUT, $row['P_DSOBSERVACAO'], Param::PARAM_TYPE_STR));
			$procedure->addParam(new Param('P_TXHISTORICO', Param::PARAM_INPUT, $row['P_TXHISTORICO'], Param::PARAM_TYPE_STR));
			$procedure->addParam(new Param('P_CDOPERADOR', Param::PARAM_INPUT, $row['P_CDOPERADOR'], Param::PARAM_TYPE_STR));
			$procedure->addParam(new Param('P_NRORG', Param::PARAM_INPUT, $row['P_NRORG'], Param::PARAM_TYPE_STR));
			$result = $procedure->execute();
        } catch (\Exception $e) {
            $msg = $this->message->convertMessage(array("TIPO" => "MENSAGEM", "MSG" => $e->getMessage()));
            $response->setError(new Error($e->getMessage(), 500));
            $response->addDataSet(new DataSet("msgError", $msg));
        }
    }
    
    public function requireInfoOrRecuse(DTO\Request $request, DTO\Response $response){
        try {
            $row = $request->getDataSet()->getRows()[0];
		    $this->solAltServPropCom($row, $response);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function importCardTrab(DTO\Request $request, DTO\Response $response){
        
        try {
            $row = $request->getDataset()->getRows()[0];
            
            $connection = $this->connection;
            if($row['RECAL']==='S'){
                //$row = $this->Tco01200CardapioDaPropostaService->getCDMarcaSolicitada($row, $connection);
                $row = $this->Tco01200CardapioDaPropostaService->getNRConfigServPropCom($row, $connection);
                $row = $this->Tco01200CardapioDaPropostaService->getGrupoPorcGram($row, $connection);
                
                $row['L_NRCONFIGCARDBASE'] = $this->createLista($row['NRCONFIGCARDBASE']);
                $row['L_PORCGRAMCARDBASE'] = $this->createLista($row['PORCGRAMCARDBASE']);
                
                //$row['L_MARCASSOLICITADA'] = $this->createLista($row['CDMARCASOLICITADA']);
                $connection->beginTransaction();
                
                $this->Tco01200CardapioDaPropostaService->removeCardTrabOfDetalheservpropcom($row, $connection);
                
                $this->Tco01200CardapioDaPropostaService->executeProcedureDeletaCardTrab($row, $connection);
                
                $row["IDORIGEM"] = "PLANEJAMENTO";
                
                $callback = $this->Tco01200CardapioDaPropostaService->executeProcedureImport($row, $connection);
                
                if(!empty($callback['P_LISTAERROS'])){
                    $struct = array(
                        'TIPO' => 'LISTA',
                        'CDFILIAL' => $this->environment->getCdFilial(),
                        'NRLISTA'  => $callback['P_LISTAERROS']
                    );  
                    $response->addDataSet(new DataSet("ERROR", $this->message->convertMessage($struct)));
                    $response->addDataSet(new DataSet("LISTA", $struct));
                    $connection->rollback();
                    $callback['P_NRCARDAPIOTRAB'] = $row['NRCARDAPIOTRAB'];
                
                    $callback['NRDETALHESERVPROPCOM'] = $row['NRDETALHESERVPROPCOM'];
                    $callback['NRDETSERVPROPCOMPLAN'] = $row['NRDETSERVPROPCOMPLAN'];
                    $connection->beginTransaction();
                    $this->Tco01200CardapioDaPropostaService->updateCardTrabOfDetalheservpropcom($callback);
                    $connection->commit();
                } else {
                    $callback['NRDETALHESERVPROPCOM'] = $row['NRDETALHESERVPROPCOM'];
                    $callback['NRDETSERVPROPCOMPLAN'] = $row['NRDETSERVPROPCOMPLAN'];
                    $callback['DTCUSTO'] = $row['DTCUSTO'];
                    $connection->commit();
                    $connection->beginTransaction();
                    $this->Tco01200CardapioDaPropostaService->updateCardTrabOfDetalheservpropcom($callback);
                    $connection->commit();
                    $response->addDataSet(new DataSet("SUCCESS", $callback));
                }
            }
            else if($row['RECAL']==='N'){
                $connection->beginTransaction();
                $callback = $this->Tco01200CardapioDaPropostaService->executeProcedureCusto($row, $connection);
                 
                if(!empty($callback['P_LISTAERROS'])){
                    $struct = array(
                        'TIPO' => 'LISTA',
                        'CDFILIAL' => $this->environment->getCdFilial(),
                        'NRLISTA'  => $callback['P_LISTAERROS']
                    );  
                    $response->addDataSet(new DataSet("ERROR", $this->message->convertMessage($struct)));
                    $response->addDataSet(new DataSet("LISTA", $struct));
                    $connection->rollback();

                } else {
                    $connection->commit();
                    $callback['DTCUSTO'] = $row['DTCUSTO'];
                    $response->addDataSet(new DataSet("SUCCESS", $callback));
                }
            }
        } catch (\Exception $e) {
            $connection->rollback();
            $response->setError(new Error($e->getMessage(), 500));
        }
       
    }
    
    private function createLista($dados) {
        $nrlista = $this->newCode->getCodeByTableName('LISTA', $this->environment->getNrorgTrab(), 1, 10, false);
        
        foreach($dados as $data) {
            $this->lista->insertLista($nrlista, $data);
        }
        
        return $nrlista;
    }
    
    public function getListaError(DTO\Request $request, DTO\Response $response){
        try{
            $row = $request->getDataset()->getRows()[0];
            $struct = array(
                'TIPO' => 'LISTA',
                'CDFILIAL' => $row["CDFILIALLISTA"],
                'NRLISTA'  => $row["NRLISTA"]
            );
            $listaErro = $this->message->convertMessage($struct);
            $response->addDataSet(new DataSet("LISTAERROR", $listaErro));
        } catch(\Exception $e){
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function getCardTrab (DTO\Request $request, DTO\Response $response){
        try{
            $filter = $request->getFilterCriteria();
            $conditions = $filter->getConditions();
            if(count($conditions)!=0){
                $cardTrab = $this->Tco01200CardapioDaPropostaService->getCardTrab($conditions[0]["value"]);
                $custosCard = $this->Tco01200CardapioDaPropostaService->getCustosCardTrab($conditions[0]["value"]);
                $custosCol = $this->Tco01200CardapioDaPropostaService->getCustosCol($conditions[0]["value"]);
                }
            if(!empty($cardTrab)){
                $dataSet = $this->buildCardapio($cardTrab, $custosCard, $custosCol);
                $dataSet = new DataSet('getCardTrab', $dataSet);
            } else {
                $dataSet = new DataSet('getCardTrab', []);
            }
            $response->addDataSet($dataSet);
        } catch(\Exception $e){
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    private function buildCardapio ($dataSet, $custosCard, $custosCol){
        $day = 1;
        $semana = 1;
        $newData = array();
        $costPerColumn = $this->getCostPerColumn($dataSet, $custosCard, $custosCol);
        $newData = $costPerColumn;
        foreach ($dataSet as $key => &$row) {
            $newRow = [];
            if($row['NRDIASEMANA'] == $day && $row['NRSEMANA'] == $semana){
                $newRow = $this->buildNewRow($newRow, $row, $custosCard);
                array_push($newData, $newRow);
                $row['LABELCEL'] = $this->concatConsumoPrato($row);
                array_push($newData, $row);
                $day++;
            } else if($row['NRDIASEMANA'] < $day && $row['NRSEMANA'] != $semana){
                $newRow = $this->buildNewRow($newRow, $row, $custosCard);
                array_push($newData, $newRow);
                $row['LABELCEL'] = $this->concatConsumoPrato($row);
                array_push($newData, $row);
                $semana++;
                $day = 2;    
            } else {
                $row['LABELCEL'] = $this->concatConsumoPrato($row);
                array_push($newData, $row);
            }
        }
        return $newData;
    }
    
    private function concatConsumoPrato($row){
        if(!empty($row['VRPECONSCARDTRAB'])){
            if(round(($row['VRPECONSCARDTRAB']/100) * $row['QTCOMENSAIS'], 5) == 1 ){
                $consumo = 1;
                $row['LABELCEL'] = $consumo." ".$row['NMPRATO'];
            } else {
                $consumo = round($row['VRPECONSCARDTRAB'], 2);
                $row['LABELCEL'] = $consumo."% ".$row['NMPRATO'];
            }
            return $row['LABELCEL'];
        } else {
            return $row['NMPRATO'];
        }
    }
    
    private function buildNewRow ($newRow, $row, $custosCard){
        $newRow['LABELCEL'] = $row['QTCOMENSAIS'];
        $newRow['LABELDIA'] = $row['LABELDIA'];
        $newRow['NRCONFIGCARDTRAB'] = null;
        $newRow['LABELTPPRAT'] = 'Comensais';
        $newRow['NRDIASEMANA'] = $row['NRDIASEMANA'];
        $newRow['NRSEMANA'] = $row['NRSEMANA'];
        $newRow['NRDIACARDTRAB'] = $row['NRDIACARDTRAB'];
        $newRow['NRCARDAPIOTRAB'] = $row['NRCARDAPIOTRAB'];
        $newRow['CUSTOTOTAL'] = number_format($custosCard[0]['CUSTOTOTAL'], 2);
        $newRow['CUSTOALIMENTAR'] = number_format($custosCard[0]['CUSTOALIMENTAR'], 2);
        $newRow['CUSTODESCARTAVEIS'] = number_format($custosCard[0]['CUSTODESCARTAVEIS'], 2);
        $newRow['CUSTOLIMPEZA'] = number_format($custosCard[0]['CUSTOLIMPEZA'], 2);
        $newRow['NRORDEM'] = -1;
        return $newRow;
    }
    
    private function getCostPerColumn($data, $custosCard, $custosCol){
        $newRow = [];
        $newData = array();
        $day = $data[0]['NRDIASEMANA'];
        $week = $data[0]['NRSEMANA'];
        $i = 0;
        $newData = $this->getBlankCel($newData, $newRow, $data, $custosCard);    
        while($data[$i]['NRSEMANA'] == $week && $data[$i]['NRDIASEMANA'] == $day){
            $newRow['LABELCEL'] = number_format($custosCol[$i]['CUSTOPORTPPRATO'], 2);
            $newRow['LABELDIA'] = "Custo";
            $newRow['NRCONFIGCARDTRAB'] = $data[$i]['NRCONFIGCARDTRAB'];
            $newRow['CDTIPOPRAT'] = $data[$i]['CDTIPOPRAT'];
            $newRow['LABELTPPRAT'] = $data[$i]['LABELTPPRAT'];
            $newRow['NRDIASEMANA'] = 0;
            $newRow['NRSEMANA'] = 0;
            $newRow['NRCARDAPIOTRAB'] = $data[$i]['NRCARDAPIOTRAB'];
            $newRow['CUSTOTOTAL'] = number_format($custosCard[0]['CUSTOTOTAL'], 2);
            $newRow['CUSTOALIMENTAR'] = number_format($custosCard[0]['CUSTOALIMENTAR'], 2);
            $newRow['CUSTODESCARTAVEIS'] = number_format($custosCard[0]['CUSTODESCARTAVEIS'], 2);
            $newRow['CUSTOLIMPEZA'] = number_format($custosCard[0]['CUSTOLIMPEZA'], 2);
            $newRow['NRORDEM'] = $data[$i]['NRORDEM'];
            array_push($newData, $newRow);
            $i++;
        }
        return $newData;
        
    }
    
    private function getBlankCel ($newData, $newRow, $data, $custosCard){
        $newRow['LABELCEL'] = null;
        $newRow['LABELDIA'] = "Custo";
        $newRow['NRCONFIGCARDTRAB'] = null;
        $newRow['LABELTPPRAT'] = 'Comensais';
        $newRow['NRDIASEMANA'] = 0;
        $newRow['NRSEMANA'] = 0;
        $newRow['CDTIPOPRAT'] = null;
        $newRow['NRCARDAPIOTRAB'] = $data[0]['NRCARDAPIOTRAB'];
        $newRow['NRORDEM'] = -1;
        $newRow['CUSTOTOTAL'] = number_format($custosCard[0]['CUSTOTOTAL'], 2);
        $newRow['CUSTOALIMENTAR'] = number_format($custosCard[0]['CUSTOALIMENTAR'], 2);
        $newRow['CUSTODESCARTAVEIS'] = number_format($custosCard[0]['CUSTODESCARTAVEIS'], 2);
        $newRow['CUSTOLIMPEZA'] = number_format($custosCard[0]['CUSTOLIMPEZA'], 2);
        array_push($newData, $newRow);
        return $newData;
    }
    
    public function confirmSelectedBrand (DTO\Request $request, DTO\Response $response){
        try{
            $row = $request->getRow();
            $row['PRECO'] = $this->returnProductPrice($row);
            $this->saveProdPropCom($row, $response);
            $this->saveProdCardTrab($row, $response);
            $response->addDataSet(new DataSet("confirmSelectedBrand", array()));
        } catch(\Exception $e){
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    private function returnProductPrice($row){
        if((float)$row['VRPEACRESCIMO'] > 0){
            return $row['PRECO'] + ($row['PRECO']*($row['VRPEACRESCIMO']/100));
        } else {
            return $row['PRECO'];
        }
    }
    
    private function saveProdPropCom ($row, $response){
        try{
            if(empty($row["NRPRODUTOPROPCOM"])){
                $row["NRPRODUTOPROPCOM"] = $this->newCode->getCodeByTableName('PRODUTOPROPCOM', $this->environment->getNrOrgTrab());
            }
            $rowProdPropCom = $this->buildRowPropCom($row);
            $rowProdPropCom[0]["__is_new"] = $this->Tco01200CardapioDaPropostaService->verifyIsNewProdPropCom($rowProdPropCom);
            $dataSet = new DataSet("produtopropcom", $rowProdPropCom);
            $request = new DTO\Request\DataSet($dataSet, "", "", "");
            $rows = $this->crudService->getRowsToSave($request, 'produtopropcom');
            $this->crudService->save('produtopropcom', $rows);
        } catch(\Exception $e){
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    private function buildRowPropCom($row){
        return array(
            array(
                "NRPRODUTOPROPCOM" => $row["NRPRODUTOPROPCOM"], 
                "NRDETALHESERVPROPCOM" => empty($row["NRDETSERVPROPCOMPLAN"]) ? $row["NRDETALHESERVPROPCOM"] : $row["NRDETSERVPROPCOMPLAN"], 
                "CDPRODUTO" => $row["CDPRODUTO"], 
                "CDMARCASOLICITADA" => $row["CDMARCASOLICITADA"], 
                "CDMARCAESCOLHIDA" => $row["CDMARCA"], 
                "VRPEACRESCIMO" => $row["VRPEACRESCIMO"], 
                "NRORG" => $this->environment->getNrOrg()
            )
        );
    }
    
    private function saveProdCardTrab ($row, $response){
        try{
            if(empty($row["NRPRODUTOCARDTRAB"])){
                $row["NRPRODUTOCARDTRAB"] = $this->newCode->getCodeByTableName('PRODUTOCARDTRAB', $this->environment->getNrOrgTrab());
            }
            $rowProdCardTrab = $this->buildRowCardTrab($row);
            $rowProdCardTrab[0]["__is_new"] = $this->Tco01200CardapioDaPropostaService->verifyIsNewProdCardTarb($rowProdCardTrab);
            $dataSet = new DataSet("produtocardtrab", $rowProdCardTrab);
            $request = new DTO\Request\DataSet($dataSet, "", "", "");
            $rows = $this->crudService->getRowsToSave($request, 'produtocardtrab');
            $this->crudService->save('produtocardtrab', $rows);
        } catch(\Exception $e){
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    private function buildRowCardTrab($row){
        return array(
            array(
                "NRPRODUTOCARDTRAB" => $row["NRPRODUTOCARDTRAB"], 
                "NRCARDAPIOTRAB" => $row["NRCARDAPIOTRAB"], 
                "CDPRODUTO" => $row["CDPRODUTO"], 
                "CDMARCA" => $row["CDMARCA"], 
                "VRCUSTO" => $row["PRECO"],
                "NRPRODLISTAPRECOTCO" => $row["NRPRODLISTAPRECOTCO"],
                "NRORG" => $this->environment->getNrOrg()
            )
        );
    }
    
    public function effect(DTO\Request $request, DTO\Response $response){
        
        try {
            $row = $request->getRow();
            
            $connection = $this->connection;
            $connection->beginTransaction();
            
            $procedure = new StoredProcedure($connection, 'EFETIVA_SERVICOPROPCOM');
            
            $procedure->addParam(new Param('P_NRSERVICOPROPCOM', Param::PARAM_INPUT,  $row['NRSERVICOPROPCOM'],             Param::PARAM_TYPE_INT));
            $procedure->addParam(new Param('P_CDFILIAL',         Param::PARAM_INPUT,  $row['CDFILIAL'],                     Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CDSERVFILI',       Param::PARAM_INPUT,  $row['CDSERVFILI'],                   Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_DTINICARD',        Param::PARAM_INPUT,  $row['P_DTINICARD'],                  Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_NUM_MESES',        Param::PARAM_INPUT,  $row['NUMMESES'],                     Param::PARAM_TYPE_INT));
            $procedure->addParam(new Param('P_CDOPERADOR',       Param::PARAM_INPUT,  $this->environment->getCdoperador(),  Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_NRORG',            Param::PARAM_INPUT,  $this->environment->getNrOrg(),       Param::PARAM_TYPE_INT));
            $procedure->addParam(new Param('P_CDFILIALLOGADA',   Param::PARAM_INPUT,  $this->environment->getCdFilial(),    Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_LISTAERROS',       Param::PARAM_OUTPUT, null,                                 Param::PARAM_TYPE_STR,20));
            
            $result = $procedure->execute();
            if(!empty($result['P_LISTAERROS'])){
                $struct = array(
                    'TIPO' => 'LISTA',
                    'CDFILIAL' => $this->environment->getCdFilial(),
                    'NRLISTA'  => $result['P_LISTAERROS']
                );  
                $response->addDataSet(new DataSet("ERROR", $this->message->convertMessage($struct)));
                $connection->rollback();
            
            } else {
                $connection->commit();
                $response->addDataSet(new DataSet("SUCCESS", $result));
            }
        } catch (\Exception $e) {
            $msg = $this->message->convertMessage(array("TIPO" => "MENSAGEM", "MSG" => $e->getMessage()));
            $response->addDataSet(new DataSet("msgError", !is_string($msg[0])? $msg: array(array('MSGCODE' => 'TCO01200_ERRO_EXEC_ROTINA', 'originalMessage'=> $msg))));
            $connection->rollback();
        }
       
    }
    
    /**
     * Retorna dados para abertura de widget de
     * serviços complementares.
     * 
     * @param int|float $nrServicoPropCom
     * 
     * @return array dados de serviços complementares.
     */
    public function getServCompl(DTO\Request $request, DTO\Response $response){
        try{
            $row = $request->getRow();
            $nrServicoPropCom = $row['NRSERVICOPROPCOM'];
            $this->entityManager->beginTransaction();
            $procedure = new StoredProcedure($this->connection, 'SERVCOMPLEMENTAR_SERVPROPCOM');
            $procedure->addParam(new Param('P_NRSERVICOPROPCOM', Param::PARAM_INPUT,  $nrServicoPropCom,                   Param::PARAM_TYPE_INT));
            $procedure->addParam(new Param('P_CDOPERADOR',       Param::PARAM_INPUT,  $this->environment->getCdoperador(), Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_NRORG',            Param::PARAM_INPUT,  $this->environment->getNrOrg(),      Param::PARAM_TYPE_INT));
            $procedure->addParam(new Param('P_CDFILIALLOGADA',   Param::PARAM_INPUT,  $this->environment->getCdFilial(),   Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_LISTACARD',        Param::PARAM_OUTPUT, null,                                Param::PARAM_TYPE_STR, 20));
            $procedure->addParam(new Param('P_PLANEJAMENTO',     Param::PARAM_INPUT,  'S',                                 Param::PARAM_TYPE_STR));
            
            $result = $procedure->execute();
            
            $this->entityManager->commit();
            
            
            if(isset($result['P_LISTACARD']) && $result['P_LISTACARD']){
                $result = $this->Tco01200CardapioDaPropostaService->getServComplByNrLista($result['P_LISTACARD']);
            } else {
                $result = [];   
            }
            
            $response->addDataSet(new DataSet("servComplData", $result));
        } catch (\Exception $e){
            $msg = $this->message->convertMessage(array("TIPO" => "MENSAGEM", "MSG" => $e->getMessage()));
            $response->addDataSet(new DataSet("msgError", $msg));
            $this->entityManager->rollback();
        }
    }
    
    public function getErrorServComp (DTO\Request $request, DTO\Response $response){
        try{
            $row = $request->getRow();
            $nrLista = $row['NRLISTAERROS'];
            $cdFilial = $this->environment->getCdFilial();
            $result = $this->message->convertMessage(array("TIPO" => "LISTA", "CDFILIAL" => $cdFilial, "NRLISTA" => $nrLista));
            $response->addDataSet(new DataSet("SUCCESS", $result));
        } catch(\Exception $e){
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function getInfoADestacar (DTO\Request $request, DTO\Response $response){
        $row = $request->getRow();
        $paginasADestacar = [];
        $servico = $this->Tco01200CardapioDaPropostaService->getInfoServPropCom($row['NRSERVICOPROPCOM']);
        $comensaisCardapio = 0;
        if (count($servico) > 0){
            $servico = $servico[0];
            $nrDetalheServPropCom = (!empty($servico['NRDETSERVPROPCOMPLAN']) ) ? $servico['NRDETSERVPROPCOMPLAN'] : $servico['NRDETALHESERVPROPCOM'];
            $detalhe = $this->Tco01200CardapioDaPropostaService->getDetalheServPropCom($nrDetalheServPropCom)[0];
            //Somente destaca páginas se tiver solicitação pendente ao planejamento
            if (!(($row['IDSERVICOPROPCOM'] == 'CONCLUIDO') ||
                  ($row['IDSERVICOPROPCOM'] == 'APROVADO') ||
                  ($row['IDSERVICOPROPCOM'] == 'EFETIVADO') ||
                  ($row['IDSERVICOPROPCOM'] == 'RECUSADO') ||
                  ($row['IDSERVICOPROPCOM'] == 'NAOSOLICITADO') ||
                  ($row['IDSERVICOPROPCOM'] == 'FINALIZADOPLANEJAMENTO') ||
                  ($row['IDSERVICOPROPCOM'] == 'AGUARDANDOGN'))){
                $incidencias = $this->Tco01200CardapioDaPropostaService->getIncidencias($servico['NRDETALHESERVPROPCOM'], $servico['NRDETSERVPROPCOMPLAN']);
                $produtos = $this->Tco01200CardapioDaPropostaService->getProdutos($servico['NRDETALHESERVPROPCOM'], $servico['NRDETSERVPROPCOMPLAN']);
                $historico = $this->Tco01200CardapioDaPropostaService->getUltimoHistorico($servico['NRSERVICOPROPCOM']);
                if (!empty($detalhe['NRLISTA'])){
                    $paginasADestacar[] = 'Lista de Erros do Cálculo';
                }
                else{
                    if (count($incidencias) > 0){
                        $paginasADestacar[] = 'Incidências';
                    }
                    if (count($incidencias) > 0){
                        $paginasADestacar[] = 'Produtos';
                    }
                    if (count($historico) > 0){
                        $historico = $historico[0];
                        if (!empty($historico['DSOBSERVACAO'])){
                            $paginasADestacar[] = 'Observações';
                        }
                    }
                }
            }
            $comensaisCardapio = $this->Tco01200CardapioDaPropostaService->getComensaisCardapio($detalhe['NRCARDAPIOTRAB']);
        }
        
        $response->addDataSet(new DataSet("paginasADestacar", $paginasADestacar));
        $response->addDataSet(new DataSet("comensaisCardapio", [$comensaisCardapio]));
    }
    
    public function replicaPratos (DTO\Request $request, DTO\Response $response) {
        $row = $request->getRow();
        try{
            $this->Tco01200CardapioDaPropostaService->procedureReplicaPratos($row);
        }catch(\Exception $e){
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function getPratos(DTO\Request $request, DTO\Response $response){
        $row = $request->getRow();
        try{
            $retorno = $this->Tco01200CardapioDaPropostaService->getPratos($row);
            $response->addDataSet(new DataSet("pratos", $retorno));
        }catch(\Exception $e){
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function getReceita(DTO\Request $request, DTO\Response $response){
        $row = $request->getRow();
        try{
            $retorno = $this->Tco01200CardapioDaPropostaService->getReceita($row);
            $response->addDataSet(new DataSet("receita", $retorno));
        }catch(\Exception $e){
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function substituiProduto(DTO\Request $request, DTO\Response $response) {
        $row = $request->getRow();
        
        $row['PRATOS'] = array();
        
        if(isset($row['NMPRATO']) && $row['NMPRATO'] != ""){
            foreach ($row['NMPRATO'] as $prato) {
                array_push($row['PRATOS'], $prato['CDFILAUXPRAT'].$prato['CDPRATO']);
            }
        }    
        
        $row['PRATOS'] = sizeof($row['PRATOS']) > 0? implode('_', $row['PRATOS']): 'T';
        
        $itemsReceitas = $this->Tco01200CardapioDaPropostaService->retornaPratosReceitaCardapioTrabalho($row);
        
        
        $receitaNaoAtualizada = array();
        $dataSetItensReceitas = array();
        
        foreach($itemsReceitas as &$item) {
            if (isset($item['CDPRODUTO_NOVO'])) {
                array_push($receitaNaoAtualizada, array(
                    "MSGCODE"=> "TCO01200_PRODUTO_NAO_ATUALIZADO",
                    "PARAMS"=> array( "CDPRATO"=> $item["CDPRATO"],
                                      "NMPRATO"=> $item["NMPRATO"],
                                      "CDPRODUTO"=> $item["CDPRODUTO_NOVO"],
                                      "NMPRODUTO"=> $item["NMPRODUTO_NOVO"] )
                ));
            } else {
                $item['CDPRODUTO']          = $row['CDPRODESTO'];
                $item['QTPRODRECCARDTRAB']  = ($row['QTSUBSPRODUTO']/100)*$item['QTPRODRECCARDTRAB'];
                $item['QTBRUTACARDTRABUNR'] = ($row['QTSUBSPRODUTO']/100)*$item['QTBRUTACARDTRABUNR'];
                $item['changed']            = true;
                $item['__is_new']           = false;
                array_push($dataSetItensReceitas, $item);
            }
        }
        
        if(count($dataSetItensReceitas) > 0) {
            $this->incluiProdutoCardapioTrab($row);
            $this->Tco01200CardapioDaPropostaService->atualizaListaPrecoProduto($row);
        }
        
        $dataSet = new DataSet("recepratcardtrab", $dataSetItensReceitas);
        $newRequest = new DTO\Request\DataSet($dataSet, "", "", "");
        $receitasToSave = $this->crudService->getRowsToSave($newRequest, 'recepratcardtrab');
        $response->addDataSet(new DataSet("ATUALIZADOS", $dataSetItensReceitas));
        $response->addDataSet(new DataSet("NAO_ATUALIZADOS", $receitaNaoAtualizada));
        $this->crudService->save('recepratcardtrab', $receitasToSave); 
        
    }
    
    private function incluiProdutoCardapioTrab($row) {
        $produtosExistentes = $this->Tco01200CardapioDaPropostaService->retornaProdutoCardapioTrab($row);
        if (sizeof($produtosExistentes) == 0) {
            $rowsProduto = array(
                array(
                    "NRPRODUTOCARDTRAB"   => $this->newCode->getCodeByTableName('PRODUTOCARDTRAB', $this->environment->getNrOrgTrab()),
                    "NRCARDAPIOTRAB"      => $row['NRCARDAPIOTRAB'], 
                    "CDPRODUTO"           => $row['CDPRODESTO'], 
                    "CDMARCA"             => $row['CDMARCA'], 
                    "VRCUSTO"             => $row['VRCUSTO'], 
                    "NRPRODLISTAPRECOTCO" => $row['NRLISTAPRECOTCO'], 
                    "NROG"                => $this->environment->getNrOrgTrab(), 
                    "changed"             => true, 
                    "__is_new"            => true 
                )
            );
        } else {
            $rowsProduto = array();
            
            foreach($produtosExistentes as $produto) {
                array_push($rowsProduto, array( "NRPRODUTOCARDTRAB"   => $produto['NRPRODUTOCARDTRAB'],
                                                "NRCARDAPIOTRAB"      => $produto['NRCARDAPIOTRAB'], 
                                                "CDPRODUTO"           => $produto['CDPRODUTO'], 
                                                "CDMARCA"             => $row['CDMARCA'], 
                                                "VRCUSTO"             => $row['VRCUSTO'], 
                                                "NRPRODLISTAPRECOTCO" => $produto['NRPRODLISTAPRECOTCO'], 
                                                "NROG"                => $this->environment->getNrOrgTrab(), 
                                                "changed"             => true, 
                                                "__is_new"            => false ));
            }
        }
        
        $dataSet = new DataSet("produtocardtrab", $rowsProduto);
        $newRequest = new DTO\Request\DataSet($dataSet, "", "", "");
        $produtosToSave = $this->crudService->getRowsToSave($newRequest, 'produtocardtrab');
        
        $this->crudService->save('produtocardtrab', $produtosToSave);
    }
    public function replicaComensais (DTO\Request $request, DTO\Response $response) {
        $row = $request->getRow();
        try{
            $this->Tco01200CardapioDaPropostaService->procedureReplicaComensais($row);
        }catch(\Exception $e){
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    public function selecionarPrecoProduto (DTO\Request $request, DTO\Response $response) {
        $row = $request->getRow();
        try{
            $con = $this->entityManager->getConnection();
            $con->beginTransaction();
            $this->Tco01200CardapioDaPropostaService->selecionarPrecoProduto($row);
            $con->commit();
        }catch(\Exception $e){
            $con->rollback();
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function alteraObservacao(DTO\Request $request, DTO\Response $response){
        $row = $request->getRow();
        $alterados = $row['ALTERADOS'];
        try{
            $conn = $this->entityManager->getConnection();
            $conn->beginTransaction();
            $this->Tco01200CardapioDaPropostaService->alteraObservacao($alterados);
            $conn->commit();
        }catch(\Exception $e){
            $conn->rollback();
            $response->setError(new Error($e->getMessage(), 500));
        }    
    }
    
    public function verificaProdJaEmListaPreco(DTO\Request $request, DTO\Response $response){
        $row = $request->getRow();
        try{
            $result = $this->Tco01200CardapioDaPropostaService->verificaProdJaEmListaPreco($row);
            $response->addDataSet(new DataSet('produtos', $result));
        }catch(\Exception $e){
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function confirmaImportacaoProduto(DTO\Request $request, DTO\Response $response){
        $row = $request->getRow();
        try{
            $conn = $this->entityManager->getConnection();
            $conn->beginTransaction();
            $result = $this->Tco01200CardapioDaPropostaService->confirmarImportacaoPreco($row);
            if(!empty($result['P_LISTAERROS'])){
                $struct = array(
                    'TIPO' => 'LISTA',
                    'CDFILIAL' => $this->environment->getCdFilial(),
                    'NRLISTA'  => $result['P_LISTAERROS']
                );  
                $response->addDataSet(new DataSet("ERROR", $this->message->convertMessage($struct)));
            }
            $conn->commit();
        }catch(\Exception $e){
            $conn->rollback();
            $response->setError(new Error($e->getMessage(), 500));
        }    
    }
    
    public function saveEvento(DTO\Request $request, DTO\Response $response){
        $row = $request->getRow();
        try{
            $result = $this->Tco01200CardapioDaPropostaService->saveEvento($row);
        }catch(\Exception $e){
            $response->setError(new Error($e->getMessage(), 500));
        }   
    }
    
    public function delEvento(DTO\Request $request, DTO\Response $response){
        $row = $request->getRow();
        try{
            $result = $this->Tco01200CardapioDaPropostaService->delEvento($row);
        }catch(\Exception $e){
            $response->setError(new Error($e->getMessage(), 500));
        }    
    }
    
}