<?php
namespace Teknisa\TCO\Services;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response\Error;
use Teknisa\GER\Services\CrudService;
use Doctrine\DBAL\Connection;
use Exception;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DataSource\FilterCriteria;

class Tco01200CardapioDaPropostaService extends \Teknisa\GER\Controllers\TeknisaCrud{
    
    protected $connection;
    protected $environment;
    protected $crudservice;
    protected $parameterbag;
    protected $dataSourceManager;
    protected $tcoUtil;
    protected $listas;
    
    public function __construct($crudservice, $parameterbag, $entityManager, $environment, $dataSourceManager, $tcoUtil, $listas){
        $this->crudservice   = $crudservice;
        $this->parameterbag  = $parameterbag;
        $this->entityManager = $entityManager;
        $this->connection    = $entityManager->getConnection();
        $this->environment   = $environment;
        $this->dataSourceManager = $dataSourceManager;
        $this->tcoUtil = $tcoUtil; 
        $this->listas = $listas;
        
        parent::__construct($crudservice, $parameterbag);
    }
    
    public function generateNewOrder($dataSet){
        $sql = "SELECT MAX(NRORDEM) AS NRORDEM FROM CONFIGCARDTRAB WHERE NRCARDAPIOTRAB = :NRCARDAPIOTRAB";
        $params = array(
            "NRCARDAPIOTRAB" => $dataSet->getRows()[0]["NRCARDAPIOTRAB"]
        );
	    $query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute($params);
        $result = $query->fetchAll();
        $dataSet->getRows()[0]["NRORDEM"] = $result[0]["NRORDEM"] + 1;
        return $dataSet;
    }
    
    public function hasPrato($dataSet){
        $data = $dataSet->getRows()[0];
        $sql = "SELECT DISTINCT NRCONFIGCARDTRAB FROM COMPCARDTRAB WHERE NRCARDAPIOTRAB = :NRCARDAPIOTRAB AND NRCONFIGCARDTRAB = :NRCONFIGCARDTRAB";
        $params = array(
            "NRCARDAPIOTRAB" => $data["NRCARDAPIOTRAB"],
            "NRCONFIGCARDTRAB" => $data["NRCONFIGCARDTRAB"]
        );
	    $query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute($params);
        $result = $query->fetchAll();
        return (empty($result));
    }
    
    public function getNivelPrato(){
        $sql = "SELECT CDPICTPRAT FROM PARAMGERAL";
	    $query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute();
        $result = $query->fetchAll();
        return sizeof(explode('.', $result[0]['CDPICTPRAT']));
    }
    
    public function getFilialParamTco(){
        $sql = "SELECT CDFILIAL FROM PARAMTCO";
	    $query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute();
        $result = $query->fetchAll();
        return empty($result[0]['CDFILIAL']) ? "" : $result[0]['CDFILIAL'];
    }
    
    public function getDadosPrato($row){
        $sql = "SELECT PRATO.CDFILAUXPRAT, PRATO.CDPRATO, PRATO.NMPRATO, PRATO.IDATIVO, (CASE WHEN (PRATO.CDFILAUXPRAT = 'P') THEN 'P' ELSE 'F' END) AS IDARVORE, RECE_UTIL_TCO (PRATO.CDFILAUXPRAT, PRATO.CDPRATO, :CDFILIAL, :NRSERVICOPROPOSTA, :NRPADRAOQUALIDADE, :CDREGIAO, :NRCARDAPIOTRAB) AS TIPO_RECEITA, PRATO.NRORG FROM PRATO WHERE (CDFILAUXPRAT = 'P' OR CDFILAUXPRAT = :CDFILIAL) AND CDNVPRATO = :CDNVPRATO ORDER BY CDPRATO";
        $params = array(
            "CDFILIAL"          => $row["CDFILIAL"],
            "NRSERVICOPROPOSTA" => $row["NRSERVICOPROPOSTA"],
            "NRPADRAOQUALIDADE" => $row["NRPADRAOQUALIDADE"],
            "CDREGIAO"          => $row["CDREGIAO"],
            "CDNVPRATO"         => $row["CDNVPRATO"],
            "NRCARDAPIOTRAB"    => $row['NRCARDAPIOTRAB']
        );
	    $query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute($params);
        $result = $query->fetchAll();
        return $result;
    }
    
    public function verifyIsNewProduct($rows){
        $invalidRows = [];
        $sql = "SELECT PRODUTO.CDARVPROD, RECEPRATCARDTRAB.CDPRATO, PRODUTO.NMPRODUTO, PRATO.NMPRATO FROM RECEPRATCARDTRAB LEFT JOIN PRODUTO ON PRODUTO.CDPRODUTO = RECEPRATCARDTRAB.CDPRODUTO LEFT JOIN PRATO ON PRATO.CDPRATO = RECEPRATCARDTRAB.CDPRATO WHERE RECEPRATCARDTRAB.NRCARDAPIOTRAB = :NRCARDAPIOTRAB AND RECEPRATCARDTRAB.CDPRATO = :CDPRATO AND RECEPRATCARDTRAB.CDPRODUTO = :CDPRODUTO";
        foreach($rows as $key => &$row){
            if($row["__is_new"]){
                $params = array(
                    "NRCARDAPIOTRAB" => $row["NRCARDAPIOTRAB"],
                    "CDPRATO" => $row["CDPRATO"],
                    "CDPRODUTO" => $row["CDPRODUTO"]
                );
                $query = $this->entityManager->getConnection()->prepare($sql);
                $query->execute($params);
                $result = $query->fetchAll();
                if(!empty($result))
                    array_push($invalidRows, $result);
            }
        }
        return $invalidRows;
    }
    
    public function buildScope($row){
	    $tpPratoQuant = $this->getTipoPratoEQuantidade($row);
	    $gramPorc = $this->getGramaturaEPorcionamento($row);
	    
	    $dsativcli = empty($tpPratoQuant["DSATIVCLI"]) ? '' : $tpPratoQuant["DSATIVCLI"]; 
	    $nmtipocontrato = empty($tpPratoQuant["NMTIPOCONTRATO"]) ? '' : $tpPratoQuant["NMTIPOCONTRATO"]; 
	    $nmpadraoqualidade = empty($tpPratoQuant["NMPADRAOQUALIDADE"]) ? '' : $tpPratoQuant["NMPADRAOQUALIDADE"]; 
	    $nmtipopublico = empty($tpPratoQuant["NMTIPOPUBLICO"]) ? '' : $tpPratoQuant["NMTIPOPUBLICO"]; 
	    $tiposprato = empty($tpPratoQuant["TIPOSPRATO"]) ? '' : $tpPratoQuant["TIPOSPRATO"];
        $qtsegsex = empty($tpPratoQuant["QTSEGSEX"]) ? '' : $tpPratoQuant["QTSEGSEX"]; 
        $qtsabado = empty($tpPratoQuant["QTSABADO"]) ? '' : $tpPratoQuant["QTSABADO"]; 
        $qtdomferi = empty($tpPratoQuant["QTDOMFERI"]) ? '' : $tpPratoQuant["QTDOMFERI"];
        $gramPorc = empty($gramPorc) ? '' : $gramPorc;
        
	    $html =    "<div class = 'content'>
                        <span class = 'header-item flex'>Escopo</span>
                        <div class = 'proprety-flex'>
                            <div class = 'flex'>
                                <span class = 'header-item'>Setor:</span>
                                <span class = 'value-item'></span>
                            </div>
                            
                            <div class = 'flex'>
                                <span class = 'header-item'>Ramo de Atividade:</span>
                                <span class = 'value-item'>".$dsativcli."</span>
                            </div>
                            
                            <div class = 'flex'>
                                <span class = 'header-item'>Tipo de Contrato:</span>
                                <span class = 'value-item'>".$nmtipocontrato."</span>
                            </div>
                            
                            <div class = 'flex'>
                                <span class = 'header-item'>Padrão de Qualidade:</span>
                                <span class = 'value-item'>".$nmpadraoqualidade."</span>
                            </div>
                            
                            <div class = 'flex'>
                                <span class = 'header-item'>Público:</span>
                                <span class = 'value-item'>".$nmtipopublico."</span>
                            </div>
                        </div>
                        
                        <span class = 'block-item'>Tipos de Prato:</span>
                        <span class = 'tipos-prato'>".$tiposprato."</span>
            
                        <span class = 'block-item'>Refeições Estimadas:</span>
                        <span class = 'tipos-prato'><b class = 'bold'>2ª a 6ª: </b> ".$qtsegsex."
                        <b class = 'space-left bold'> Sabádos: </b> ".$qtsabado."
                        <b class = 'space-left bold'> Domingos e Feriados: </b> ".$qtdomferi." </span>
            
                        <span class = 'block-item'>Porcionamento e Gramatura:</span>
                        <table>
                                ".$gramPorc."
                        </table>
            
                    </div>
                ";
	    
        return $html;
    }
    
    private function getTipoPratoEQuantidade($row){
        $sql = "SELECT SERVICOPROPCOM.NRSERVICOPROPCOM, SERVICOPROPCOM.NRVERSAOPROPCOM, SERVICOPROPCOM.NRSERVICOPROPOSTA, SERVICOPROPCOM.NRTIPOPUBLICO, TIPOPUBLICO.NMTIPOPUBLICO, SERVICOPROPCOM.NRPADRAOQUALIDADE, CONFIGSERVPROPCOM.CDTIPOPRAT, TIPOPRAT.NMTIPOPRAT, SERVICOPROPCOM.QTSEGSEX, SERVICOPROPCOM.QTSABADO, SERVICOPROPCOM.QTDOMFERI, SERVICOPROPCOM.NRORG, PROPOSTACOMERCIAL.CDATIVCLI, PROPOSTACOMERCIAL.NRTIPOCONTRATO, PADRAOQUALIDADE.NMPADRAOQUALIDADE, ATIVCLIENTE.DSATIVCLI, SEGMERCADO.DSSEGMER, TIPOCONTRATO.NMTIPOCONTRATO FROM SERVICOPROPCOM INNER JOIN CONFIGSERVPROPCOM ON CONFIGSERVPROPCOM.NRDETALHESERVPROPCOM = NVL( SERVICOPROPCOM.NRDETSERVPROPCOMPLAN, SERVICOPROPCOM.NRDETALHESERVPROPCOM ) INNER JOIN VERSAOPROPCOM ON SERVICOPROPCOM.NRVERSAOPROPCOM = VERSAOPROPCOM.NRVERSAOPROPCOM INNER JOIN PROPOSTACOMERCIAL ON PROPOSTACOMERCIAL.NRPROPOSTACOMERCIAL = VERSAOPROPCOM.NRPROPOSTACOMERCIAL LEFT JOIN PADRAOQUALIDADE ON PADRAOQUALIDADE.NRPADRAOQUALIDADE = SERVICOPROPCOM.NRPADRAOQUALIDADE LEFT JOIN TIPOPRAT ON TIPOPRAT.CDTIPOPRAT = CONFIGSERVPROPCOM.CDTIPOPRAT LEFT JOIN SEGMERCADO ON PROPOSTACOMERCIAL.CDSEGMER = SEGMERCADO.CDSEGMER LEFT JOIN ATIVCLIENTE ON PROPOSTACOMERCIAL.CDATIVCLI = ATIVCLIENTE.CDATIVCLI LEFT JOIN TIPOCONTRATO ON PROPOSTACOMERCIAL.NRTIPOCONTRATO = TIPOCONTRATO.NRTIPOCONTRATO LEFT JOIN TIPOPUBLICO ON TIPOPUBLICO.NRTIPOPUBLICO = SERVICOPROPCOM.NRTIPOPUBLICO WHERE SERVICOPROPCOM.NRSERVICOPROPOSTA =:NRSERVICOPROPOSTA AND SERVICOPROPCOM.NRSERVICOPROPCOM =:NRSERVICOPROPCOM";
        $params = array(
            "NRSERVICOPROPOSTA" => $row["P_NRSERVICOPROPOSTA"],
            "NRSERVICOPROPCOM" => $row["P_NRSERVICOPROPCOM"]
        );
	    $query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute($params);
        $result = $query->fetchAll();
        $tpPratoQuant = $this->buildStringTipoPratoQuant($result);
        return $tpPratoQuant;
    }
    
    private function getGramaturaEPorcionamento($row){
        $sql = "SELECT SPC.NRSERVICOPROPCOM, GTP.CDGRTIPOPR, GTP.NMGRTIPOPR, P.NMPORCIONAMENTO, P.CDPORCIONAMENTO, NVL(GCB.VRGRAMATURA, '') AS VRGRAMATURA, NVL(GCB.IDTIPOGRAMATURA, '') AS IDTIPOGRAMATURA, SPC.NRORG FROM SERVICOPROPCOM SPC LEFT JOIN CONFGRUPOTPPROPCOM CGPC ON SPC.NRDETALHESERVPROPCOM = CGPC.NRDETALHESERVPROPCOM LEFT JOIN GRAMATURACARDBASE GCB ON GCB.NRGRAMATURACARDBASE = CGPC.NRGRAMATURACARDBASE LEFT JOIN PORCIONAMENTO P ON P.NRPORCIONAMENTO = CGPC.NRPORCIONAMENTO LEFT JOIN GRTIPOPR GTP ON GTP.CDGRTIPOPR = CGPC.CDGRTIPOPR WHERE SPC.NRSERVICOPROPOSTA =:NRSERVICOPROPOSTA AND SPC.NRSERVICOPROPCOM =:NRSERVICOPROPCOM";
        $params = array(
            "NRSERVICOPROPOSTA" => $row["P_NRSERVICOPROPOSTA"],
            "NRSERVICOPROPCOM" => $row["P_NRSERVICOPROPCOM"]
        );
	    $query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute($params);
        $result = $query->fetchAll();
        $gramPorc = $this->buildHtmlGramPorc($result);
        return $gramPorc;
    }
    
    private function buildStringTipoPratoQuant($result){
        $tiposPrato = ""; $qtsegsex = ""; $qtsabado = ""; $qtdomferi = "";
        $padraoqualidade = ""; $dssegmer = ""; $nmtipocontrato = ""; $dsativcli = "";
        $tpPratoQuant = "";
        if(!empty($result)){
            
            $length = sizeof($result)-1;
            
            foreach($result as $key => &$data){
                if($key != $length)
                    $tiposPrato = $tiposPrato.$data["NMTIPOPRAT"].", ";
                else
                    $tiposPrato = $tiposPrato.$data["NMTIPOPRAT"];
            }
            
            $tpPratoQuant = array(
                "TIPOSPRATO" => $tiposPrato,
                "QTSEGSEX" => $result[0]["QTSEGSEX"],
                "QTSABADO" => $result[0]["QTSABADO"],
                "QTDOMFERI" => $result[0]["QTDOMFERI"],
                "NMTIPOCONTRATO" => $result[0]["NMTIPOCONTRATO"],
                "DSATIVCLI" => $result[0]["DSATIVCLI"],
                "NMTIPOPUBLICO" => $result[0]["NMTIPOPUBLICO"],
                "NMPADRAOQUALIDADE" => $result[0]["NMPADRAOQUALIDADE"]
            );
            
        }
        
        return $tpPratoQuant;
    }
    
    private function buildHtmlGramPorc($result){
        $html = "";
        foreach ($result as $key => &$data) {
            $html .= "<tr>"; 
            $html .= "<td class = 'space-right'>".$data["NMGRTIPOPR"]."</td>";
            $html .= "<td class = 'space-right'>".$data["NMPORCIONAMENTO"]."</td>";
            $html .= "<td class = 'space-right'>".$data["VRGRAMATURA"]."</td>";
            $html .= "<td class = 'space-right'>".$data["IDTIPOGRAMATURA"]."</td>";
            $html .= "</tr>";
        }
        return $html;
    }
    
    public function updateResponsibleOperator($row){
        $sql    = "UPDATE DETALHESERVPROPCOM SET CDRESPONSAVELPLAN = :CDRESPONSAVELPLAN WHERE NRDETALHESERVPROPCOM = NVL(:NRDETSERVPROPCOMPLAN, :NRDETALHESERVPROPCOM) AND NRSERVICOPROPCOM = :NRSERVICOPROPCOM AND (NRCARDAPIOTRAB = :NRCARDAPIOTRAB OR :NRCARDAPIOTRAB IS NULL)";
        $params = array(
            "CDRESPONSAVELPLAN"     => $row["CDOPERADOR"],
            "NRDETALHESERVPROPCOM"  => $row["NRDETALHESERVPROPCOM"],
            "NRDETSERVPROPCOMPLAN"  => $row["NRDETSERVPROPCOMPLAN"],
            "NRSERVICOPROPCOM"      => $row["NRSERVICOPROPCOM"],
            "NRCARDAPIOTRAB"        => $row["NRCARDAPIOTRAB"]
        );
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $row["CDOPERADOR"];
    }
    
    private function setParamInRowToProcedure($row, $result){
       if(!empty($result)){
            $row["P_IDORIGEM"] = $result[0]["IDORIGEM"];
            $row["P_IDDESTINO"] = $result[0]["IDDESTINO"];
            $row["P_DSOBSERVACAO"] = $result[0]["DSOBSERVACAO"];
            $row["P_TXHISTORICO"] = $result[0]["TXHISTORICO"];
        } 
        
        return $row;
    }
    
     public function removeCardTrabOfDetalheservpropcom($row, $connection){
        $sql = "UPDATE DETALHESERVPROPCOM SET NRCARDAPIOTRAB = NULL, CDFILIALLISTA = NULL, NRLISTA = NULL WHERE NRDETALHESERVPROPCOM = NVL(:NRDETSERVPROPCOMPLAN, :NRDETALHESERVPROPCOM)";
        $params = array(
            "NRDETALHESERVPROPCOM" => $row["NRDETALHESERVPROPCOM"],
            "NRDETSERVPROPCOMPLAN" => empty($row["NRDETSERVPROPCOMPLAN"]) ? null : $row["NRDETSERVPROPCOMPLAN"]
        );
        $query = $connection->prepare($sql);
        $query->execute($params);
    }
    
    public function executeProcedureDeletaCardTrab($row, $connection){
        
        $procedure = new StoredProcedure($connection, 'DELETA_CARDTRAB');
        $procedure->addParam(new Param('P_NRCARDAPIOTRAB', Param::PARAM_INPUT,  $row['NRCARDAPIOTRAB'],  Param::PARAM_TYPE_INT));
        
        $procedure->execute();
    }
    
     public function getCDMarcaSolicitada($row, $connection){
        $sql    = "SELECT CDMARCASOLICITADA, CDPRODUTO, VRPEACRESCIMO FROM PRODUTOPROPCOM WHERE NRDETALHESERVPROPCOM = NVL(:NRDETSERVPROPCOMPLAN, :NRDETALHESERVPROPCOM)";
        $params = array(
            "NRDETALHESERVPROPCOM" => $row["NRDETALHESERVPROPCOM"],
            "NRDETSERVPROPCOMPLAN" => empty($row["NRDETSERVPROPCOMPLAN"]) ? null : $row["NRDETSERVPROPCOMPLAN"]
        );
        $query = $connection->prepare($sql);
        $query->execute($params);
        $result = $query->fetchAll();
        if(!empty($result)){
            $row["CDMARCASOLICITADA"] = $this->concatPorcGram($result);
        } else {
            $row["CDMARCASOLICITADA"] = array();
        }
        return $row;
    }
    
    private function concatMarca($result, $connection){
        $rows = array();
        $concat = "";
        foreach ($result as $key => &$row) {
            $cdproduto = empty($row["CDPRODUTO"]) ? '' : $row["CDPRODUTO"];
            $cdmarcasolicitada = empty($row["CDMARCASOLICITADA"]) ? '' : $row["CDMARCASOLICITADA"];
            $vrpeacrescimo = empty($row["VRPEACRESCIMO"]) ? '' : $row["VRPEACRESCIMO"];
            $concat = $cdproduto+'|'+$cdmarcasolicitada+'|'+$vrpeacrescimo;
            array_push($rows, $concat);
        }
        return $rows;
    }
    
     public function getNRConfigServPropCom($row, $connection){
        $sql    = "SELECT NRCONFIGCARDBASE FROM CONFIGSERVPROPCOM WHERE NRDETALHESERVPROPCOM = NVL(:NRDETSERVPROPCOMPLAN, :NRDETALHESERVPROPCOM)";
        $params = array(
            "NRDETALHESERVPROPCOM" => $row["NRDETALHESERVPROPCOM"],
            "NRDETSERVPROPCOMPLAN" => empty($row["NRDETSERVPROPCOMPLAN"]) ? null : $row["NRDETSERVPROPCOMPLAN"]
        );
        $query = $connection->prepare($sql);
        $query->execute($params);
        $result = $query->fetchAll();
        if(!empty($result)){
            $row["NRCONFIGCARDBASE"] = $this->buildArrayConfigCardBase($result);
        } else {
            $row["NRCONFIGCARDBASE"] = array();
        }
        return $row;
    }
    
    private function buildArrayConfigCardBase($rows){
        $rowsConfig = array();
        foreach ($rows as $row) {
            $rowsConfig[] = $row["NRCONFIGCARDBASE"];
        }
        return $rowsConfig;
    }
    
    public function getGrupoPorcGram($row, $connection){
        $sql    = "SELECT CDGRTIPOPR, NRPORCIONAMENTO, NRGRAMATURACARDBASE, IDTIPOGRAMATURA FROM CONFGRUPOTPPROPCOM WHERE NRDETALHESERVPROPCOM = NVL(:NRDETSERVPROPCOMPLAN, :NRDETALHESERVPROPCOM)";
        $params = array(
            "NRDETALHESERVPROPCOM" => $row["NRDETALHESERVPROPCOM"],
            "NRDETSERVPROPCOMPLAN" => empty($row["NRDETSERVPROPCOMPLAN"]) ? null : $row["NRDETSERVPROPCOMPLAN"]
        );
        $query = $connection->prepare($sql);
        $query->execute($params);
        $result = $query->fetchAll();
        if(!empty($result)){
            $row["PORCGRAMCARDBASE"] = $this->concatPorcGram($result);
        } else {
            $row["PORCGRAMCARDBASE"] = array();
        }
        return $row;
    }
    
    private function concatPorcGram($result){
        $rows = array();
        $concat = "";
        foreach ($result as $key => &$row) {
            $cdgrtipopr = empty($row["CDGRTIPOPR"]) ? '' : $row["CDGRTIPOPR"];
            $nrporcionamento = empty($row["NRPORCIONAMENTO"]) ? '' : $row["NRPORCIONAMENTO"];
            $nrgramaturacardbase = empty($row["NRGRAMATURACARDBASE"]) ? '' : $row["NRGRAMATURACARDBASE"];
            $idtipogramatura = '';
            if($row["IDTIPOGRAMATURA"] === 'INNATURA')
                $idtipogramatura = '0';
            if($row["IDTIPOGRAMATURA"] === 'LIMPA')
                $idtipogramatura = '1';
            if($row["IDTIPOGRAMATURA"] === 'PRONTA')
                $idtipogramatura = '2';
                
            $concat = $cdgrtipopr.'|'.$nrporcionamento.'|'.$nrgramaturacardbase.'|'.$idtipogramatura;
            array_push($rows, $concat);
        }
        return $rows;
    }
    
    public function executeProcedureImport($row, $connection){
        
        $procedure = new StoredProcedure($connection, 'IMPORTA_CARDBASE_NO_CARDTRAB');
        $procedure->addParam(new Param('P_NRCARDAPIOBASE',          Param::PARAM_INPUT,  $row['NRCARDAPIOBASE'],             Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_IDORIGEM',                Param::PARAM_INPUT,  $row["IDORIGEM"],                   Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRATIVCLISEGMER',         Param::PARAM_INPUT,  $row['NRATIVCLISEGMER'],            Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_CDREGIAO',                Param::PARAM_INPUT,  $row['CDREGIAO'],                   Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_VRPEACRESCUSTO',          Param::PARAM_INPUT,  $row['VRPEACRESCUSTO'],             Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRTIPOPUBLICO',           Param::PARAM_INPUT,  $row['NRTIPOPUBLICO'],              Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_QTSEGSEX',                Param::PARAM_INPUT,  $row['QTSEGSEX'],                   Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_QTSABADO',                Param::PARAM_INPUT,  $row['QTSABADO'],                   Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_QTDOMFERI',               Param::PARAM_INPUT,  $row['QTDOMFERI'],                  Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_QTTURNOS',                Param::PARAM_INPUT,  $row['QTTURNOS'],                   Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_CONFIGURACOES',           Param::PARAM_INPUT,  $row['L_NRCONFIGCARDBASE'],         Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_GRUPOS',                  Param::PARAM_INPUT,  $row['L_PORCGRAMCARDBASE'],         Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTCUSTO',                 Param::PARAM_INPUT,  $row['DTCUSTO'],                    Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRCARDTRABCOMPLEMENTADO', Param::PARAM_INPUT,  $row['NRSERVICOPROPCOMCOMPL'],      Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRORG',                   Param::PARAM_INPUT,  $this->environment->getNrOrgTrab(), Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_CDOPERADOR',              Param::PARAM_INPUT,  $this->environment->getCdoperador(),Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFILIALLOGADA',          Param::PARAM_INPUT,  $this->environment->getCdFilial(),  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRCARDAPIOTRAB',          Param::PARAM_OUTPUT, null,                               Param::PARAM_TYPE_STR, 20));
        $procedure->addParam(new Param('P_LISTAERROS',              Param::PARAM_OUTPUT, null,                               Param::PARAM_TYPE_STR, 20));
        
        $result = $procedure->execute();
        return $result;
    }
    
    public function updateCardTrabOfDetalheservpropcom($row){
        $sql = "UPDATE DETALHESERVPROPCOM SET NRCARDAPIOTRAB = :NRCARDAPIOTRAB, CDFILIALLISTA = :CDFILIALLISTA, NRLISTA = :NRLISTA WHERE NRDETALHESERVPROPCOM = NVL(:NRDETSERVPROPCOMPLAN, :NRDETALHESERVPROPCOM)";
        if(empty($row['P_LISTAERROS'])){
            $params = array(
                "NRCARDAPIOTRAB" => $row["P_NRCARDAPIOTRAB"],
                "CDFILIALLISTA" => null,
                "NRLISTA" => null,
                "NRDETALHESERVPROPCOM" => $row["NRDETALHESERVPROPCOM"],
                "NRDETSERVPROPCOMPLAN" => empty($row["NRDETSERVPROPCOMPLAN"]) ? null : $row["NRDETSERVPROPCOMPLAN"]
            );
        } else {
            $params = array(
                "NRCARDAPIOTRAB" => $row["P_NRCARDAPIOTRAB"],
                "CDFILIALLISTA" => $this->environment->getCdFilial(),
                "NRLISTA" => $row["P_LISTAERROS"],
                "NRDETALHESERVPROPCOM" => $row["NRDETALHESERVPROPCOM"],
                "NRDETSERVPROPCOMPLAN" => empty($row["NRDETSERVPROPCOMPLAN"]) ? null : $row["NRDETSERVPROPCOMPLAN"]
            );
        }
        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }
    
    public function getServPropCom($row, $conditions){
        $valuesWithDistinctLabel = array(
            "OPERADORPLANEJAMENTO" => "OPENMOPERADOR"    
        );
        $assocFieldToTable = array(
            "CDPROPOSTACOMERCIAL" => array(
                'tableName' => 'PC'
            ),
            "NMOPERADOR" => array(
                'tableName' => 'O'
            ),
            "NMCLIENTORPROSPECT" => array(
                'tableName' => "",
                'format' => "NVL(P.NMRAZSOCPROS,C.NMRAZSOCCLIE)"
            ),
            "DTLANCAMENTO" => array(
                "tableName" => "PC",
                "format" => "TO_CHAR(tableName.NAME_COLUMN,'DD/MM/YYYY')"
            ),
            "CDVERSAOPROPCOM" => array(
                "tableName" => "VP"
            ),
            "NMSERVICOPROPOSTA" => array(
                "tableName" => "SP"
            ),
            "NMPADRAOQUALIDADE" => array(
                "tableName" => "PQ"
            ),
            "NMTIPOPUBLICO" => array(
                "tableName" => "TP"
            ),
            "IDSERVICOPROPCOM" => array(
                "tableName" => "",
                "format" => "SIT_SERVICOPROPCOM(SPC.NRSERVICOPROPCOM,'S')"
            ),
            "IDMOTIVO" => array(
                "tableName" => "",
                "format" => "(SELECT IDMOTIVO FROM HISTNOTIFPROPCOM WHERE NRSERVICOPROPCOM = SPC.NRSERVICOPROPCOM AND NRHISTNOTIFPROPCOM = ( SELECT MAX(NRHISTNOTIFPROPCOM) FROM HISTNOTIFPROPCOM WHERE NRSERVICOPROPCOM = SPC.NRSERVICOPROPCOM ))"
            ),
            "OPENMOPERADOR" => array(
                "tableName" => "",
                "format" => "OPE.NMOPERADOR"
            )
            
        );
        $queryLikeAll = $this->tcoUtil->prepareQueryLikeAll($conditions, $assocFieldToTable, $valuesWithDistinctLabel);
        $sql    = "SELECT SPC.NRSERVICOPROPCOM, PC.NRPROPOSTACOMERCIAL, SPC.NRDETSERVPROPCOMPLAN, SPC.NRDETALHESERVPROPCOM, CT.NRCARDAPIOTRAB, CT.NRLISTAPRECOTCO, SPC.NRCARDAPIOBASE, SPC.NRPADRAOQUALIDADE, PC.NRGERENTENEGOCIO, PC.NRTIPOCONTRATO, SPC.NRTIPOPUBLICO, VP.NRVERSAOPROPCOM, VP.CDVERSAOPROPCOM, SP.NRSERVICOPROPOSTA, SP.CDSERVFILI, ACSM.NRATIVCLISEGMER, DSPC.CDRESPONSAVELPLAN, P.NMPAIS, M.NMMUNICIPIO, TC.NMTIPOCONTRATO, AC.DSATIVCLI, SM.DSSEGMER, ( SELECT IDMOTIVO FROM HISTNOTIFPROPCOM WHERE NRSERVICOPROPCOM = SPC.NRSERVICOPROPCOM AND NRHISTNOTIFPROPCOM = ( SELECT MAX(NRHISTNOTIFPROPCOM) FROM HISTNOTIFPROPCOM WHERE NRSERVICOPROPCOM = SPC.NRSERVICOPROPCOM ) ) AS IDMOTIVO, PQ.CDPADRAOQUALIDADE, PQ.NMPADRAOQUALIDADE, CT.CDREGIAO, R.NMREGIAO, SPC.CDFILIAL, F.NMFILIAL, SIT_SERVICOPROPCOM(SPC.NRSERVICOPROPCOM,'S') AS IDSERVICOPROPCOM, PC.CDCLIENTE, C.NMRAZSOCCLIE, PC.CDPROPOSTACOMERCIAL, PC.CDPROSPECT, P.NMRAZSOCPROS, NVL(PC.CDPROSPECT,PC.CDCLIENTE) AS CDCLIENTORPROSPECT, NVL(P.NMRAZSOCPROS,C.NMRAZSOCCLIE) AS NMCLIENTORPROSPECT, TO_CHAR(PC.DTLANCAMENTO,'DD/MM/YYYY') AS DTLANCAMENTO, PC.IDRETENCAO, PC.CDSEGMER, PC.CDATIVCLI, PC.IDEDITAL, PC.IDSUGERIDO, PC.CDPAIS, PC.SGESTADO, PC.CDMUNICIPIO, PC.DSENDERECO, NVL(SPC.QTSEGSEX,0) AS QTSEGSEX, NVL(SPC.QTSABADO,0) AS QTSABADO, NVL(SPC.QTDOMFERI,0) AS QTDOMFERI, SPC.QTTOTDIAS, SPC.QTTURNOS, SPC.QTTOTREFEICOES, SP.NMSERVICOPROPOSTA, SP.CDSERVICOPROPOSTA, OPE.CDOPERADOR AS CDOPERADORPLANEJAMENTO, OPE.NMOPERADOR AS OPERADORPLANEJAMENTO, O.NMOPERADOR, CT.DTCUSTO, CT.VRPEACRESCUSTO, SPC.NRSERVICOPROPCOMCOMPL, DSPC.NRLISTA, DSPC.CDFILIALLISTA, TP.CDTIPOPUBLICO, TP.NMTIPOPUBLICO, PC.NRORG FROM SERVICOPROPCOM SPC INNER JOIN VERSAOPROPCOM VP ON SPC.NRVERSAOPROPCOM = VP.NRVERSAOPROPCOM INNER JOIN PROPOSTACOMERCIAL PC ON PC.NRPROPOSTACOMERCIAL = VP.NRPROPOSTACOMERCIAL INNER JOIN SERVICOPROPOSTA SP ON SP.NRSERVICOPROPOSTA = SPC.NRSERVICOPROPOSTA INNER JOIN DETALHESERVPROPCOM DSPC ON DSPC.NRSERVICOPROPCOM = SPC.NRSERVICOPROPCOM AND DSPC.NRDETALHESERVPROPCOM = NVL(SPC.NRDETSERVPROPCOMPLAN,SPC.NRDETALHESERVPROPCOM) LEFT JOIN CARDAPIOTRAB CT ON CT.NRCARDAPIOTRAB = DSPC.NRCARDAPIOTRAB LEFT JOIN REGIAO R ON CT.CDREGIAO = R.CDREGIAO LEFT JOIN GERENTENEGOCIO GN ON PC.NRGERENTENEGOCIO = GN.NRGERENTENEGOCIO LEFT JOIN OPERADOR O ON GN.CDOPERADOR = O.CDOPERADOR LEFT JOIN PROSPECT P ON PC.CDPROSPECT = P.CDPROSPECT LEFT JOIN CLIENTE C ON PC.CDCLIENTE = C.CDCLIENTE LEFT JOIN FILIAL F ON SPC.CDFILIAL = F.CDFILIAL LEFT JOIN PADRAOQUALIDADE PQ ON PQ.NRPADRAOQUALIDADE = SPC.NRPADRAOQUALIDADE LEFT JOIN SEGMERCADO SM ON PC.CDSEGMER = SM.CDSEGMER LEFT JOIN ATIVCLISEGMER ACSM ON ACSM.CDSEGMER = SM.CDSEGMER AND ACSM.CDATIVCLI = PC.CDATIVCLI LEFT JOIN ATIVCLIENTE AC ON PC.CDATIVCLI = AC.CDATIVCLI LEFT JOIN TIPOCONTRATO TC ON PC.NRTIPOCONTRATO = TC.NRTIPOCONTRATO LEFT JOIN PAIS P ON PC.CDPAIS = P.CDPAIS LEFT JOIN MUNICIPIO M ON PC.CDMUNICIPIO = M.CDMUNICIPIO AND PC.CDPAIS = M.CDPAIS AND PC.SGESTADO = M.SGESTADO LEFT JOIN TIPOPUBLICO TP ON TP.NRTIPOPUBLICO = SPC.NRTIPOPUBLICO LEFT JOIN OPERADOR OPE ON OPE.CDOPERADOR = DSPC.CDRESPONSAVELPLAN WHERE ( PC.CDPROPOSTACOMERCIAL =:CDPROPOSTACOMERCIAL OR :CDPROPOSTACOMERCIAL = 'T' ) AND ( ( VALOR_NA_LISTA(TO_CHAR(O.CDOPERADOR),:CDOPERADOR) > 0 ) OR INSTR(:CDOPERADOR, O.CDOPERADOR) <> 0 OR :CDOPERADOR = 'T' ) AND ( ( ( VALOR_NA_LISTA(TO_CHAR(PC.CDPROSPECT),:CDPROSPECT) > 0 ) OR INSTR(:CDPROSPECT, PC.CDPROSPECT) <> 0 OR :CDPROSPECT = 'T' ) AND ( ( VALOR_NA_LISTA(TO_CHAR(PC.CDCLIENTE),:CDCLIENTE) > 0 ) OR INSTR(:CDCLIENTE, PC.CDCLIENTE) <> 0 OR :CDCLIENTE = 'T' ) ) AND ( ( VALOR_NA_LISTA(TO_CHAR(SP.CDSERVICOPROPOSTA),:CDSERVICOPROPOSTA) > 0 ) OR INSTR(:CDSERVICOPROPOSTA, SP.CDSERVICOPROPOSTA) <> 0 OR :CDSERVICOPROPOSTA = 'T' ) AND ( ( VALOR_NA_LISTA(TO_CHAR(PQ.CDPADRAOQUALIDADE),:CDPADRAOQUALIDADE) > 0 ) OR INSTR(:CDPADRAOQUALIDADE, PQ.CDPADRAOQUALIDADE) <> 0 OR :CDPADRAOQUALIDADE = 'T' ) AND ( ( VALOR_NA_LISTA(TO_CHAR(TP.CDTIPOPUBLICO),:CDTIPOPUBLICO) > 0 ) OR INSTR(:CDTIPOPUBLICO, TP.CDTIPOPUBLICO) <> 0 OR :CDTIPOPUBLICO = 'T' ) AND ( ( SIT_SERVICOPROPCOM(SPC.NRSERVICOPROPCOM,'S') =:IDSERVICOPROPCOM ) OR INSTR(:IDSERVICOPROPCOM, SPC.IDSERVICOPROPCOM) <> 0 OR (:IDSERVICOPROPCOM = 'T' ) ) AND ( ( SELECT IDMOTIVO FROM HISTNOTIFPROPCOM WHERE NRSERVICOPROPCOM = SPC.NRSERVICOPROPCOM AND NRHISTNOTIFPROPCOM = ( SELECT MAX(NRHISTNOTIFPROPCOM) FROM HISTNOTIFPROPCOM WHERE NRSERVICOPROPCOM = SPC.NRSERVICOPROPCOM ) ) =:IDMOTIVO OR (:IDMOTIVO = 'T' ) ) AND ( ( TRUNC(PC.DTLANCAMENTO) BETWEEN :DTINI AND :DTFIN ) ) $queryLikeAll ORDER BY PC.CDPROPOSTACOMERCIAL ASC";
        $params = array(
            "CDPROPOSTACOMERCIAL" => empty($row["CDPROPOSTACOMERCIAL"]) ? 'T' : $row["CDPROPOSTACOMERCIAL"],
            "CDOPERADOR" => empty($row["CDOPERADOR"]) ? 'T' : $row["CDOPERADOR"],
            "CDPROSPECT" => empty($row["CDPROSPECT"]) ? 'T' : $row["CDPROSPECT"],
            "CDCLIENTE" => empty($row["CDCLIENTE"]) ? 'T' : $row["CDCLIENTE"],
            "DTINI" => $row["DTINI"],
            "DTFIN" => $row["DTFIN"],
            "CDSERVICOPROPOSTA" => empty($row["CDSERVICOPROPOSTA"]) ? 'T' : $row["CDSERVICOPROPOSTA"],
            "CDPADRAOQUALIDADE" => empty($row["CDPADRAOQUALIDADE"]) ? 'T' : $row["CDPADRAOQUALIDADE"],
            "CDTIPOPUBLICO" => empty($row["CDTIPOPUBLICO"]) ? 'T' : $row["CDTIPOPUBLICO"],
            "IDSERVICOPROPCOM" => empty($row["IDSERVICOPROPCOM"]) ? 'T' : $row["IDSERVICOPROPCOM"],
            "IDMOTIVO" => empty($row["IDMOTIVO"]) ? 'T' : $row["IDMOTIVO"]
        );
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        $result = $query->fetchAll();
        return $result;
    }
    
    public function getCardTrab($row){
        $sql    = "SELECT CARDAPIOTRAB.NRCARDAPIOTRAB, COMPCARDTRAB.NRCOMPCARDTRAB, DIACARDTRAB.NRDIACARDTRAB, DIACARDTRAB.NRSEMANA, DIACARDTRAB.NRDIASEMANA, DECODE(DIACARDTRAB.NRDIASEMANA,1,'TCODOM',2,'TCOSEG',3,'TCOTER',4,'TCOQUA',5,'TCOQUI',6,'TCOSEX',7,'TCOSAB') AS LABELDIA, CONFIGCARDTRAB.NRCONFIGCARDTRAB, CONFIGCARDTRAB.NRORDEM, CONFIGCARDTRAB.CDTIPOPRAT, TIPOPRAT.NMTIPOPRAT, CONFIGCARDTRAB.DSCOMPLEMENTO, CONFIGCARDTRAB.IDCLASSIFICACAO, CONFIGCARDTRAB.IDTEMPERATURA, COMPCARDTRAB.CDPRATO, PRATO.CDFILAUXPRAT, PRATO.NMPRATO, DIACARDTRAB.QTCOMENSAIS, CARDAPIOTRAB.NRORG, CASE WHEN CONFIGCARDTRAB.DSCOMPLEMENTO IS NOT NULL THEN TIPOPRAT.NMTIPOPRAT || ' (' || CONFIGCARDTRAB.DSCOMPLEMENTO || ')' ELSE TIPOPRAT.NMTIPOPRAT END LABELTPPRAT, CARDAPIOTRAB.CDREGIAO, REGIAO.NMREGIAO, COMPCARDTRAB.VRPECONSCARDTRAB, 0 AS CUSTOALIMENTAR, 0 AS CUSTODESCARTAVEIS, 0 AS CUSTOLIMPEZA, 0 AS CUSTOTOTAL, 0 AS CUSTOPORTPPRATO FROM CARDAPIOTRAB INNER JOIN DIACARDTRAB ON DIACARDTRAB.NRCARDAPIOTRAB = CARDAPIOTRAB.NRCARDAPIOTRAB INNER JOIN CONFIGCARDTRAB ON CONFIGCARDTRAB.NRCARDAPIOTRAB = CARDAPIOTRAB.NRCARDAPIOTRAB LEFT JOIN COMPCARDTRAB ON COMPCARDTRAB.NRCARDAPIOTRAB = CARDAPIOTRAB.NRCARDAPIOTRAB AND COMPCARDTRAB.NRCONFIGCARDTRAB = CONFIGCARDTRAB.NRCONFIGCARDTRAB AND DIACARDTRAB.NRDIACARDTRAB = COMPCARDTRAB.NRDIACARDTRAB INNER JOIN TIPOPRAT ON TIPOPRAT.CDTIPOPRAT = CONFIGCARDTRAB.CDTIPOPRAT LEFT JOIN PRATO ON PRATO.CDFILAUXPRAT = COMPCARDTRAB.CDFILAUXPRAT AND PRATO.CDPRATO = COMPCARDTRAB.CDPRATO LEFT JOIN REGIAO ON CARDAPIOTRAB.CDREGIAO = REGIAO.CDREGIAO WHERE CARDAPIOTRAB.NRCARDAPIOTRAB =:NRCARDAPIOTRAB ORDER BY DIACARDTRAB.NRSEMANA ASC, DIACARDTRAB.NRDIASEMANA ASC, DIACARDTRAB.NRDIACARDTRAB ASC, CONFIGCARDTRAB.NRORDEM ASC";
        $params = array(
            "NRCARDAPIOTRAB" => $row
        );
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll();
    }
    
    public function getCustosCol($row){
        $sql    = "SELECT CONFIGCARDTRAB.NRCONFIGCARDTRAB,
                          ROUND(CUSTO_PERC_COL_CARDTRAB(NRCARDAPIOTRAB, CONFIGCARDTRAB.NRCONFIGCARDTRAB), 2) AS CUSTOPORTPPRATO
                     FROM CONFIGCARDTRAB
                    WHERE NRCARDAPIOTRAB = :NRCARDAPIOTRAB
                    ORDER BY CONFIGCARDTRAB.NRORDEM ASC";
        $params = array(
            "NRCARDAPIOTRAB" => $row
        );
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll();
    }
    
    public function getCustosCardTrab($row){
        $sql    = "SELECT ROUND(CUSTO_PERC_CARDTRAB(:NRCARDAPIOTRAB, 'ALIMENTAR'), 2) AS CUSTOALIMENTAR, 
                          ROUND(CUSTO_PERC_CARDTRAB(:NRCARDAPIOTRAB, 'DESCARTAVEL'), 2) AS CUSTODESCARTAVEIS, 
                          ROUND(CUSTO_PERC_CARDTRAB(:NRCARDAPIOTRAB, 'LIMPEZA'), 2) AS CUSTOLIMPEZA, 
                          ROUND(CUSTO_PERC_CARDTRAB(:NRCARDAPIOTRAB), 2) AS CUSTOTOTAL FROM DUAL";
        $params = array(
            "NRCARDAPIOTRAB" => $row
        );
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll();
    }
    
    public function verifyReceCardTrabIsNew($row){
        $connection = $this->entityManager->getConnection();
        $sql = "SELECT * FROM RECEPRATCARDTRAB WHERE NRRECEPRATCARDTRAB = :NRRECEPRATCARDTRAB";
        $query = $connection->prepare($sql);
        $params = array(
            "NRRECEPRATCARDTRAB" => $row["NRRECEPRATCARDTRAB"],
        );
        $query->execute($params);
        $result = $query->fetchAll(\PDO::FETCH_ASSOC);
        return empty($result);
    }
    
    public function verifyIsNewProdPropCom($row){
        $connection = $this->entityManager->getConnection();
        $sql = "SELECT * FROM PRODUTOPROPCOM WHERE NRPRODUTOPROPCOM = :NRPRODUTOPROPCOM";
        $query = $connection->prepare($sql);
        $params = array(
            "NRPRODUTOPROPCOM" => $row[0]["NRPRODUTOPROPCOM"],
        );
        $query->execute($params);
        $result = $query->fetchAll(\PDO::FETCH_ASSOC);
        return empty($result);
    }
    
    public function verifyIsNewProdCardTarb($row){
        $connection = $this->entityManager->getConnection();
        $sql = "SELECT * FROM PRODUTOCARDTRAB WHERE NRPRODUTOCARDTRAB = :NRPRODUTOCARDTRAB";
        $query = $connection->prepare($sql);
        $params = array(
            "NRPRODUTOCARDTRAB" => $row[0]["NRPRODUTOCARDTRAB"],
        );
        $query->execute($params);
        $result = $query->fetchAll(\PDO::FETCH_ASSOC);
        return empty($result);
    }
    
     /**
     * Retorna serviços complementares de acordo com
     * o numero da lista passado por parâmetro.
     * 
     * @param int|float $nrLista
     * @param int|float $nrServicoPropCom
     * 
     * @return array serviços complementares
     */
    public function getServComplByNrLista($nrLista){
        $sql = "SELECT C.CDCARDAPIOBASE, S.NMSERVICOPROPOSTA, CASE WHEN L.CALCULADO = 'S' THEN L.CHAVE ELSE NULL END AS NRCARDAPIOTRAB, CASE WHEN L.CALCULADO = 'S' THEN NULL ELSE L.CHAVE END AS NRLISTAERROS, CASE WHEN L.CALCULADO = 'S' THEN 'N' ELSE 'S' END AS IDERRO, CASE WHEN L.CALCULADO = 'S' THEN CUSTO_PERC_CARDTRAB(L.CHAVE) ELSE 0.00 END AS VRCUSTO FROM (SELECT L.CDLISTA, INSTR(L.CDLISTA, '|', 1, 2) - 1, SUBSTR(L.CDLISTA, 1, INSTR(L.CDLISTA, '|') - 1) AS NRCARDAPIOBASE, SUBSTR(L.CDLISTA, INSTR(L.CDLISTA, '|') + 1, INSTR(L.CDLISTA, '|', 1, 2) - INSTR(L.CDLISTA, '|') -1) AS CALCULADO, SUBSTR(L.CDLISTA, INSTR(L.CDLISTA, '|', 1, 2) + 1, 50)AS CHAVE FROM LISTA L WHERE L.NRLISTA = :NRLISTA) L INNER JOIN CARDAPIOBASE C ON C.NRCARDAPIOBASE = L.NRCARDAPIOBASE INNER JOIN SERVICOPROPOSTA S ON S.NRSERVICOPROPOSTA = C.NRSERVICOPROPOSTA";

        $params = array(
            "NRLISTA"=> $nrLista
        );

        $query = $this->connection->prepare($sql);
        $query->execute($params);

        return $query->fetchAll();
    }
    
    /**
     * Retorna informações do serviço da proposta
     * 
     * @param int|float $nrServicoPropCom
     * 
     * @return servico da proposta
     */
    public function getInfoServPropCom($nrServicoPropCom){
        $sql = "SELECT NRSERVICOPROPCOM, NRDETSERVPROPCOMPLAN, NRDETALHESERVPROPCOM, SIT_SERVICOPROPCOM(NRSERVICOPROPCOM, 'PLANEJAMENTO') AS IDSERVICOPROPCOM FROM SERVICOPROPCOM WHERE NRSERVICOPROPCOM = :NRSERVICOPROPCOM";

        $params = array(
            "NRSERVICOPROPCOM"=> $nrServicoPropCom
        );

        $query = $this->connection->prepare($sql);
        $query->execute($params);

        return $query->fetchAll();
    }
    
    /**
     * Retorna informações do detalhe do serviço
     * 
     * @param int|float $nrServicoPropCom
     * 
     * @return servico da proposta
     */
    public function getDetalheServPropCom($nrDetalheServPropCom){
        $sql = "SELECT NRDETALHESERVPROPCOM, NRCARDAPIOTRAB, CDFILIALLISTA, NRLISTA FROM DETALHESERVPROPCOM WHERE NRDETALHESERVPROPCOM = :NRDETALHESERVPROPCOM";

        $params = array(
            "NRDETALHESERVPROPCOM"=> $nrDetalheServPropCom
        );

        $query = $this->connection->prepare($sql);
        $query->execute($params);

        return $query->fetchAll();
    }
    
    /**
     * Retorna informações do último histórico
     * 
     * @param int|float $nrServicoPropCom
     * 
     * @return servico da proposta
     */
    public function getUltimoHistorico($nrServicoPropCom){
        $sql = "SELECT IDMOTIVO, DSOBSERVACAO FROM HISTNOTIFPROPCOM WHERE NRHISTNOTIFPROPCOM = (SELECT MAX(NRHISTNOTIFPROPCOM) FROM HISTNOTIFPROPCOM WHERE NRSERVICOPROPCOM = :NRSERVICOPROPCOM)";

        $params = array(
            "NRSERVICOPROPCOM"=> $nrServicoPropCom
        );

        $query = $this->connection->prepare($sql);
        $query->execute($params);

        return $query->fetchAll();
    }
    
    /**
     * Retorna informações de incidências
     * 
     * @param int|float $nrServicoPropCom
     * 
     * @return servico da proposta
     */
     
    public function getIncidencias($nrDetalheServPropCom, $nrDetServPropComPla){
        $conditions = array(
            array(
                "columnName" => "NRDETALHESERVPROPCOM", 
                "operator"   => "=",
                "value"      => $nrDetalheServPropCom
            ),
            array(
                "columnName" => "NRDETSERVPROPCOMPLAN", 
                "operator"   => "=",
                "value"      => $nrDetServPropComPla
            ),
            array(
                "columnName" => "NRINCIDENCIAPROPCOM", 
                "operator"   => "IS_NOT_NULL",
                "value" => ""
            )
        );

        $dataset = $this->crudservice->getFilteredDataSet("tco01200_incidencias", $conditions)->getRows();
        
        return $dataset;
    }
    
    /**
     * Retorna informações de produtos
     * 
     * @param int|float $nrServicoPropCom
     * 
     * @return servico da proposta
     */
     
    public function getProdutos($nrDetalheServPropCom, $nrDetServPropComPla){
        $conditions = array(
            array(
                "columnName" => "NRDETALHESERVPROPCOM", 
                "operator"   => "=",
                "value"      => $nrDetalheServPropCom
            ),
            array(
                "columnName" => "NRDETSERVPROPCOMPLAN", 
                "operator"   => "=",
                "value"      => $nrDetServPropComPla
            ),
            array(
                "columnName" => "NRPRODUTOPROPCOM", 
                "operator"   => "IS_NOT_NULL",
                "value" => ""
            )
        );

        $dataset = $this->crudservice->getFilteredDataSet("tco01200_produtos", $conditions)->getRows();
        
        return $dataset;
    }
    
    public function procedureReplicaPratos($row){
        $connection = $this->entityManager->getConnection();
        
        $procedure = new StoredProcedure($connection, 'REPLICA_PRATO_CARDTRAB');
        $procedure->addParam(new Param('P_NRCARDAPIOTRAB', Param::PARAM_INPUT, $row['NRCARDAPIOTRAB'],             Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_NRCOMPCARDTRAB', Param::PARAM_INPUT, $row['NRCOMPCARDTRAB'],             Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_NRORG',          Param::PARAM_INPUT, $this->environment->getNrOrgTrab(), Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_CDOPERADOR',     Param::PARAM_INPUT, $this->environment->getCdOperador(),Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DOM',            Param::PARAM_INPUT, $row['P_DOM'],                      Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_SEG',            Param::PARAM_INPUT, $row['P_SEG'],                      Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_TER',            Param::PARAM_INPUT, $row['P_TER'],                      Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_QUA',            Param::PARAM_INPUT, $row['P_QUA'],                      Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_QUI',            Param::PARAM_INPUT, $row['P_QUI'],                      Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_SEX',            Param::PARAM_INPUT, $row['P_SEX'],                      Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_SAB',            Param::PARAM_INPUT, $row['P_SAB'],                      Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_SUBTITUIR',      Param::PARAM_INPUT, $row['SOBREPOR'],                   Param::PARAM_TYPE_STR));
        
        $result = $procedure->execute();
    }
    
    public function getPratos($row){
        $sql = "
            SELECT C.CDFILAUXPRAT,
                   C.CDPRATO,
                   P.NMPRATO,
                   COUNT(1) AS OCORRENCIAS,
                   SUM(C.VRPECONSCARDTRAB/100 * D.QTCOMENSAIS) AS QTCOMENSAIS,
                   MAX(CUSTO_PRAT_CARDTRAB(C.NRCARDAPIOTRAB, C.CDFILAUXPRAT, C.CDPRATO)) AS VRCUSTO,
                   SUM(C.VRPECONSCARDTRAB/100 * D.QTCOMENSAIS * CUSTO_PRAT_CARDTRAB(C.NRCARDAPIOTRAB, C.CDFILAUXPRAT, C.CDPRATO)) AS VRCUSTOTOTAL,
                   SUM(CASE WHEN D.QTCOMENSAIS > 0
                            THEN C.VRPECONSCARDTRAB/100 * D.QTCOMENSAIS * CUSTO_PRAT_CARDTRAB(C.NRCARDAPIOTRAB, C.CDFILAUXPRAT, C.CDPRATO) / D.QTCOMENSAIS
                       ELSE 0.00
                       END) AS VRCUSTOPERC
              FROM COMPCARDTRAB C
                   LEFT JOIN PRATO P ON P.CDFILAUXPRAT = C.CDFILAUXPRAT AND
                                        P.CDPRATO = C.CDPRATO
                   LEFT JOIN DIACARDTRAB D ON D.NRDIACARDTRAB = C.NRDIACARDTRAB
             WHERE C.NRCARDAPIOTRAB = :NRCARDAPIOTRAB
               AND C.NRDIACARDTRAB = :NRDIACARDTRAB
             GROUP BY C.CDFILAUXPRAT,
                   C.CDPRATO,
                   P.NMPRATO
        ";

        $params = array(
            "NRCARDAPIOTRAB"=> $row['NRCARDAPIOTRAB'],
            "NRDIACARDTRAB" => $row['NRDIACARDTRAB']
        );

        $query = $this->connection->prepare($sql);
        $query->execute($params);

        return $query->fetchAll();
    }
    
    public function getReceita($row){
        $sql = "
            SELECT P.CDPRODUTO,
                   P.CDARVPROD,
                   P.NMPRODUTO,
                   R.SGUNIDADE,
                   R.QTBRUTACARDTRABUNR,
                   CUSTO_PROD_CARDTRAB(R.NRCARDAPIOTRAB, R.CDPRODUTO) AS VRCUSTO,
                   R.QTBRUTACARDTRABUNR * :QTPRATO AS QTTOTAL,
                   R.QTBRUTACARDTRABUNR * :QTPRATO * CUSTO_PROD_CARDTRAB(R.NRCARDAPIOTRAB, R.CDPRODUTO) AS VRCUSTOTOTAL
              FROM RECEPRATCARDTRAB R 
                   LEFT JOIN PRODUTO P ON P.CDPRODUTO = R.CDPRODUTO
             WHERE R.NRCARDAPIOTRAB = :NRCARDAPIOTRAB
               AND R.CDFILAUXPRAT = :CDFILAUXPRAT
               AND R.CDPRATO = :CDPRATO
        ";

        $params = array(
            "QTPRATO" => $row['QTPRATO'],
            "NRCARDAPIOTRAB" => $row['NRCARDAPIOTRAB'],
            "CDFILAUXPRAT"=> $row['CDFILAUXPRAT'],
            "CDPRATO" => $row['CDPRATO']
        );

        $query = $this->connection->prepare($sql);
        $query->execute($params);

        return $query->fetchAll();
    }
    
    public function retornaPratosReceitaCardapioTrabalho($row) {
        $sql = "SELECT RECEPRATCARDTRAB.NRRECEPRATCARDTRAB, 
                       RECEPRATCARDTRAB.NRCARDAPIOTRAB, 
                       RECEPRATCARDTRAB.CDFILAUXPRAT, 
                       RECEPRATCARDTRAB.CDPRATO, 
                       PRATO.NMPRATO,
                       RECEPRATCARDTRAB.CDPRODUTO, 
                       RECEPRATCARDTRAB.QTPRODRECCARDTRAB, 
                       RECEPRATCARDTRAB.QTBRUTACARDTRABUNR, 
                       RECEPRATCARDTRAB.IDATIVO, 
                       RECEPRATCARDTRAB.NRORG,
                       (SELECT MAX(P.CDARVPROD) 
                          FROM RECEPRATCARDTRAB R 
                         INNER JOIN PRODUTO P
                            ON P.CDPRODUTO = R.CDPRODUTO
                         WHERE R.NRCARDAPIOTRAB = RECEPRATCARDTRAB.NRCARDAPIOTRAB
                           AND R.CDFILAUXPRAT = RECEPRATCARDTRAB.CDFILAUXPRAT
                           AND R.CDPRATO = RECEPRATCARDTRAB.CDPRATO
                           AND R.CDPRODUTO = :NOVO_CDPRODUTO
                           ) AS CDPRODUTO_NOVO,
                       (SELECT MAX(P.NMPRODUTO) 
                          FROM RECEPRATCARDTRAB R 
                         INNER JOIN PRODUTO P
                            ON P.CDPRODUTO = R.CDPRODUTO
                         WHERE R.NRCARDAPIOTRAB = RECEPRATCARDTRAB.NRCARDAPIOTRAB
                           AND R.CDFILAUXPRAT = RECEPRATCARDTRAB.CDFILAUXPRAT
                           AND R.CDPRATO = RECEPRATCARDTRAB.CDPRATO
                           AND R.CDPRODUTO = :NOVO_CDPRODUTO
                           ) AS NMPRODUTO_NOVO
                  FROM RECEPRATCARDTRAB 
                 INNER JOIN PRATO
                    ON PRATO.CDFILAUXPRAT = RECEPRATCARDTRAB.CDFILAUXPRAT
                   AND PRATO.CDPRATO = RECEPRATCARDTRAB.CDPRATO
                 WHERE VALOR_NA_LISTA(RECEPRATCARDTRAB.CDFILAUXPRAT||RECEPRATCARDTRAB.CDPRATO, :PRATOS) > 0 
                   AND RECEPRATCARDTRAB.NRCARDAPIOTRAB = :NRCARDAPIOTRAB 
                   AND RECEPRATCARDTRAB.CDPRODUTO = :CDPRODUTO";

        $params = array(
            "NOVO_CDPRODUTO" => $row['CDPRODESTO'],
            "PRATOS"         => $row['PRATOS'],
            "NRCARDAPIOTRAB" => $row['NRCARDAPIOTRAB'],
            "CDPRODUTO"      => $row['PRODATUAL']
        );

        $query = $this->connection->prepare($sql);
        $query->execute($params);

        return $query->fetchAll(); 
    }
    
    public function retornaProdutoCardapioTrab($row) {
        $sql = "SELECT NRPRODUTOCARDTRAB, 
                       NRCARDAPIOTRAB,
                       CDPRODUTO, 
                       CDMARCA, 
                       VRCUSTO, 
                       NRPRODLISTAPRECOTCO, 
                       NRORG
                  FROM PRODUTOCARDTRAB
                 WHERE NRCARDAPIOTRAB = :NRCARDAPIOTRAB
                   AND CDPRODUTO      = :CDPRODUTO";
        $params = array(
            "NRCARDAPIOTRAB" => $row['NRCARDAPIOTRAB'],
            "CDPRODUTO"      => $row['CDPRODESTO']
        );

        $query = $this->connection->prepare($sql);
        $query->execute($params);

        return $query->fetchAll(); 
    }
    public function executeProcedureCusto($row, $connection){
        
        $VRPEACRESCUSTO = (isset($row['VRPEACRESCUSTO'])) ? $row['VRPEACRESCUSTO'] : 0;
        $P_LISTAERROS = '';
        
        $procedure = new StoredProcedure($connection, 'IMPORTA_CUSTO_NO_CARDTRAB');
        $procedure->addParam(new Param('P_NRCARDAPIOTRAB',          Param::PARAM_INPUT,  $row['NRCARDAPIOTRAB'],             Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTCUSTO',                 Param::PARAM_INPUT,  $row['DTCUSTO'],                    Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDREGIAO',                Param::PARAM_INPUT,  $row['CDREGIAO'],                   Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_VRPEACRESCUSTO',          Param::PARAM_INPUT,  $VRPEACRESCUSTO,                    Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFILIALLOGADA',          Param::PARAM_INPUT,  $this->environment->getCdFilial(),  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDOPERADOR',              Param::PARAM_INPUT,  $this->environment->getCdoperador(),Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRORG',                   Param::PARAM_INPUT,  $this->environment->getNrOrgTrab(), Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_LISTAERROS',              Param::PARAM_OUTPUT, $P_LISTAERROS,                      Param::PARAM_TYPE_STR, 20));
        
        $result = $procedure->execute();
        return $result;
    }
    public function procedureReplicaComensais($row){
        $connection = $this->entityManager->getConnection();
        $procedure = new StoredProcedure($connection, 'REPLICA_PRATO_CARDTRAB');
        $procedure->addParam(new Param('P_NRCARDAPIOTRAB', Param::PARAM_INPUT, $row['NRCARDAPIOTRAB'],             Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_NRCOMPCARDTRAB', Param::PARAM_INPUT, $row['NRCOMPCARDTRAB'],             Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_NRORG',          Param::PARAM_INPUT, $this->environment->getNrOrgTrab(), Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_CDOPERADOR',     Param::PARAM_INPUT, $this->environment->getCdOperador(),Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DOM',            Param::PARAM_INPUT, $row['P_DOM'],                      Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_SEG',            Param::PARAM_INPUT, $row['P_SEG'],                      Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_TER',            Param::PARAM_INPUT, $row['P_TER'],                      Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_QUA',            Param::PARAM_INPUT, $row['P_QUA'],                      Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_QUI',            Param::PARAM_INPUT, $row['P_QUI'],                      Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_SEX',            Param::PARAM_INPUT, $row['P_SEX'],                      Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_SAB',            Param::PARAM_INPUT, $row['P_SAB'],                      Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_SUBTITUIR',      Param::PARAM_INPUT, $row['SOBREPOR'],                   Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_COPIA_PRATO',    Param::PARAM_INPUT, 'N',                                Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_COMENSAIS',      Param::PARAM_INPUT, $row['COMENSAIS'],                  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_1COMENSAL',      Param::PARAM_INPUT, $row['P_1COMENSAL'],                Param::PARAM_TYPE_STR));
        
        $result = $procedure->execute();
    }
    public function selecionarPrecoProduto($row){
        // Retirar o ID Selecionado de todas as linhas de preços do produto.
        $sql = "UPDATE PRODLISTAPRECOCARDTRAB
                    SET IDESCOLHIDO = 'N'
                    WHERE NRCARDAPIOTRAB = :NRCARDAPIOTRAB
                    AND CDPRODESTO = :CDPRODESTO";
        $params = array(
            "NRCARDAPIOTRAB" => $row["nrCardTrab"],
            "CDPRODESTO" => $row["cdProd"]
        );
	    $query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute($params);
        
        // Atualizar o ID Selecionado para a linha de preço selecionada.
        $sql = "UPDATE PRODLISTAPRECOCARDTRAB
                    SET IDESCOLHIDO = 'S', 
                        CDOPERULTATU = :CDOPERULTATU,
                        DTULTATU = SYSDATE
                    WHERE NRCARDAPIOTRAB = :NRCARDAPIOTRAB
                    AND NRPRODLISTAPRECOCARDTRAB = :NRPRODLISTAPRECOCARDTRAB";
        $params = array(
            "NRCARDAPIOTRAB" => $row["nrCardTrab"],
            "NRPRODLISTAPRECOCARDTRAB" => $row["nrListaPreco"],
            "CDOPERULTATU" => $this->environment->getCdOperador()
        );
	    $query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute($params);
        
        // Atualizar a tabela PRODUTOCARDTRAB com o preço selecionado.
        $sql = "UPDATE PRODUTOCARDTRAB
                    SET NRPRODLISTAPRECOCARDTRAB = :NRPRODLISTAPRECOCARDTRAB,
                        VRCUSTO = :VRCUSTO,
                        CDMARCA = :CDMARCA,
                        CDOPERULTATU = :CDOPERULTATU,
                        DTULTATU = SYSDATE
                    WHERE NRCARDAPIOTRAB = :NRCARDAPIOTRAB
                    AND CDPRODUTO = :CDPRODUTO";
        $params = array(
            "NRCARDAPIOTRAB" => $row["nrCardTrab"],
            "NRPRODLISTAPRECOCARDTRAB" => $row["nrListaPreco"],
            "CDOPERULTATU" => $this->environment->getCdOperador(),
            "VRCUSTO" => $row["vrcusto"],
            "CDMARCA" => $row["cdmarca"],
            "CDPRODUTO" => $row["cdProd"]
        );
	    $query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute($params);
        
        
        $this->atualizaProdutoPropCom($row["nrCardTrab"], $row["nrListaPreco"]);
    }
    
    public function confirmarImportacaoPreco($row){
        
        
        $VRPEACRESCUSTO = (isset($row['VRPEACRESCUSTO'])) ? $row['VRPEACRESCUSTO'] : 0;
        $P_LISTAERROS = '';
        $produtos = $this->listas->criarListaValores($row['PRODUTOS']);
        
        $procedure = new StoredProcedure($this->entityManager->getConnection(), 'IMPPRECO_CARDTRAB');
        $procedure->addParam(new Param('P_NRCARDAPIOTRAB',          Param::PARAM_INPUT,  $row['NRCARDAPIOTRAB'],             Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_PRODUTOS',                Param::PARAM_INPUT,  $produtos,                          Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTCUSTO',                 Param::PARAM_INPUT,  $row['DTCUSTO'],                    Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDREGIAO',                Param::PARAM_INPUT,  $row['CDREGIAO'],                   Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_VRPEACRESCUSTO',          Param::PARAM_INPUT,  $VRPEACRESCUSTO,                    Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFILIALLOGADA',          Param::PARAM_INPUT,  $this->environment->getCdFilial(),  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDOPERADOR',              Param::PARAM_INPUT,  $this->environment->getCdoperador(),Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRORG',                   Param::PARAM_INPUT,  $this->environment->getNrOrgTrab(), Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_LISTAERROS',              Param::PARAM_OUTPUT, $P_LISTAERROS,                      Param::PARAM_TYPE_STR, 20));
        
        $result = $procedure->execute();
        return $result;
    }
    
    
    public function alteraObservacao($alterados){
        
        foreach($alterados as $alterado){
            $sql = "UPDATE CONFGRUPOTPPROPCOM
                       SET DSOBSERVACAO = :DSOBSERVACAO,
                           CDOPERULTATU = :CDOPERADOR,
                           DTULTATU = SYSDATE
                     WHERE NRCONFGRUPOTPPROPCOM = :NRCONFGRUPOTPPROPCOM";
            
            $params = array(
                "DSOBSERVACAO" => $alterado["DSOBSERVACAO"],
                "CDOPERADOR" => $this->environment->getCdOperador(),
                "NRCONFGRUPOTPPROPCOM" => $alterado["NRCONFGRUPOTPPROPCOM"]
            );
    	    $query = $this->entityManager->getConnection()->prepare($sql);
            $query->execute($params);
        }
        
    }
    
    public function atualizaListaPrecoProduto($row){
        $sql = "UPDATE PRODUTOCARDTRAB
                   SET NRPRODLISTAPRECOCARDTRAB = :NRPRODLISTAPRECOCARDTRAB
                 WHERE NRCARDAPIOTRAB = :NRCARDAPIOTRAB
                   AND CDPRODUTO = :CDPRODUTO";
        $params = array(
            "NRPRODLISTAPRECOCARDTRAB" => $row["NRPRODLISTAPRECOCARDTRAB"],
            "NRCARDAPIOTRAB" => $row['NRCARDAPIOTRAB'],
            "CDPRODUTO"      => $row['CDPRODESTO']
        );
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        
        $sql = "UPDATE PRODLISTAPRECOCARDTRAB
                   SET IDESCOLHIDO = 'N'
                 WHERE NRCARDAPIOTRAB = :NRCARDAPIOTRAB
                   AND CDPRODESTO = :CDPRODESTO";
        $params = array(
            "NRCARDAPIOTRAB" => $row['NRCARDAPIOTRAB'],
            "CDPRODESTO"      => $row['CDPRODESTO']
        );
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        
        $sql = "UPDATE PRODLISTAPRECOCARDTRAB
                   SET IDESCOLHIDO = 'S',
                       CDOPERULTATU = :CDOPERADOR,
                       DTULTATU = SYSDATE
                 WHERE NRCARDAPIOTRAB = :NRCARDAPIOTRAB AND
                       NRPRODLISTAPRECOCARDTRAB = :NRPRODLISTAPRECOCARDTRAB";
        $params = array(
            "NRCARDAPIOTRAB" => $row['NRCARDAPIOTRAB'],
            "NRPRODLISTAPRECOCARDTRAB" => $row['NRPRODLISTAPRECOCARDTRAB'],
            "CDOPERADOR" => $this->environment->getCdOperador()
        );
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        
        $this->atualizaProdutoPropCom($row['NRCARDAPIOTRAB'], $row['NRPRODLISTAPRECOCARDTRAB']);
    }
    
    
    public function verificaProdJaEmListaPreco($row){
        $produtos = $this->listas->criarListaValores($row['PRODUTOS']);
        $sql = "SELECT NRPRODLISTAPRECOCARDTRAB
                    FROM PRODLISTAPRECOCARDTRAB
                    WHERE NRCARDAPIOTRAB = :NRCARDAPIOTRAB
                    AND VALOR_NA_LISTA(CDPRODESTO, :P_PRODUTOS) > 0";
        $params = array(
            "NRCARDAPIOTRAB" => $row['NRCARDAPIOTRAB'],
            "P_PRODUTOS"     => $produtos
        );
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll();
    }
    
    public function saveEvento($row){
        
        if($row["VRPERCENTUAL"] <= 0 || ( empty($row["NREVENTOCARDTRAB"]) && empty($row["NRCARDAPIOTRAB"]) ) || empty("DSEVENTO") || empty("CDMES"))
            throw new \Exception("DADOS_INCOMPLETOS", 400);
            
        $sql = "UPDATE EVENTOCARDTRAB
                   SET CDMES = :CDMES,
                       DSEVENTO = :DSEVENTO,
                       VRPERCENTUAL = :VRPERCENTUAL,
                       CDOPERULTATU = :CDOPERADOR,
                       DTULTATU = SYSDATE
                 WHERE NREVENTOCARDTRAB = :NREVENTOCARDTRAB";
                   
        $params = [
            "CDMES" => $row["CDMES"],
            "DSEVENTO" => $row["DSEVENTO"],
            "VRPERCENTUAL" => $row["VRPERCENTUAL"],
            "NREVENTOCARDTRAB" => $row['NREVENTOCARDTRAB'],
            "CDOPERADOR" => $this->environment->getCdOperador()
        ];
        
        if($row['__is_new']){
            $sql = "INSERT INTO EVENTOCARDTRAB
                    (NREVENTOCARDTRAB, NRCARDAPIOTRAB,
                     CDMES, DSEVENTO, VRPERCENTUAL,
                     NRORG, NRORGULTATU, NRORGINCLUSAO,
                     CDOPERULTATU, CDOPERINCLUSAO,
                     DTULTATU, DTINCLUSAO)
                    VALUES
                    (RETORNA_NOVO_CODIGO('EVENTOCARDTRAB', 1), :NRCARDAPIOTRAB,
                     :CDMES, :DSEVENTO, :VRPERCENTUAL,
                     :NRORG, :NRORG, :NRORG,
                     :CDOPERADOR, :CDOPERADOR,
                     SYSDATE, SYSDATE)";
                       
            $params = [
                "NRCARDAPIOTRAB" => $row['NRCARDAPIOTRAB'],
                "CDMES" => $row["CDMES"],
                "DSEVENTO" => $row["DSEVENTO"],
                "VRPERCENTUAL" => $row["VRPERCENTUAL"],
                "NRORG" => $this->environment->getNrOrgTrab(),
                "CDOPERADOR" => $this->environment->getCdOperador()
            ];    
        }
        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }
    
    public function delEvento($row){
        try{
            $eventosAExcluir = $row["eventosAExcluir"];
            $conn = $this->connection;
            $conn->beginTransaction();
            
            foreach($eventosAExcluir as $evento){
                $sql = "DELETE FROM EVENTOCARDTRAB
                         WHERE NREVENTOCARDTRAB = :NREVENTOCARDTRAB";
                           
                $params = [
                    "NREVENTOCARDTRAB" => $evento['NREVENTOCARDTRAB']
                ];
                $query = $conn->prepare($sql);
                $query->execute($params);
            }
            
            $conn->commit();
        }catch(\Exception $e){
            $conn->rollback();
        }    
    }
    
    public function atualizaProdutoPropCom($nrCardapioTrab, $nrProdListaPrecoCardTrab){
        //Verificar se tem ProdutoPropCom selecionado
        $sql = "SELECT NRDETALHESERVPROPCOM
                  FROM DETALHESERVPROPCOM
                 WHERE NRCARDAPIOTRAB = :NRCARDAPIOTRAB";
        
        $params = array(
            "NRCARDAPIOTRAB" => $nrCardapioTrab
        );
        
        $query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute($params);
        $result = $query->fetch();
        if(!$result) return;
	    $nrDetalheServPropCom = $result['NRDETALHESERVPROPCOM'];
	    
	    $sql = "SELECT CDPRODESTO, CDMARCA, VRPEACRESCIMO
	              FROM PRODLISTAPRECOCARDTRAB
                 WHERE NRCARDAPIOTRAB = :P_NRCARDAPIOTRAB
                   AND NRPRODLISTAPRECOCARDTRAB = :P_NRPRODLISTAPRECOCARDTRAB";
        $params = array(
            "P_NRCARDAPIOTRAB" => $nrCardapioTrab,
            "P_NRPRODLISTAPRECOCARDTRAB" => $nrProdListaPrecoCardTrab
        );           
	    $query = $this->entityManager->getConnection()->prepare($sql);
	    $query->execute($params);
	    $result = $query->fetch();
	    $cdProduto = null;
	    $cdMarca = null;
	    $vrPeAcrecimo = null;
	    if($result){
	       $cdProduto = $result['CDPRODESTO'];
	       $cdMarca = $result['CDMARCA'];
	       $vrPeAcrecimo = $result['VRPEACRESCIMO'];
	    }
	    else {
	        return;
	    }
	   
        //Verificar se tem ProdutoPropCom selecionado
        $sql = "SELECT NRPRODUTOPROPCOM
                  FROM PRODUTOPROPCOM
                 WHERE NRDETALHESERVPROPCOM = :NRDETALHESERVPROPCOM
                   AND CDPRODUTO = :CDPRODUTO";
        
        $params = array(
            "NRDETALHESERVPROPCOM" => $nrDetalheServPropCom,
            "CDPRODUTO" => $cdProduto
        );
        $query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute($params);
        $result = $query->fetch();
        if(!$result){
            $nrProdutoPropCom = intval($this->tcoUtil->novoCodigo('PRODUTOPROPCOM', 1));
            $sql = "INSERT INTO PRODUTOPROPCOM
                    (NRPRODUTOPROPCOM, NRDETALHESERVPROPCOM,
                     CDPRODUTO, CDMARCAESCOLHIDA,
                     VRPEACRESCIMO,          
                     NRORG, NRORGINCLUSAO, NRORGULTATU,
                     CDOPERINCLUSAO, CDOPERULTATU,
                     DTINCLUSAO, DTULTATU)
                    VALUES
                    (:NRPRODUTOPROPCOM, :NRDETALHESERVPROPCOM,
                     :CDPRODUTO, :CDMARCAESCOLHIDA,
                     :VRPEACRESCIMO,          
                     :NRORG, :NRORG, :NRORG,
                     :CDOPERADOR, :CDOPERADOR,
                     SYSDATE, SYSDATE)";
            $params = array(
                "NRPRODUTOPROPCOM" => $nrProdutoPropCom,
                "NRDETALHESERVPROPCOM" => $nrDetalheServPropCom,
                "CDPRODUTO" => $cdProduto,
                "CDMARCAESCOLHIDA" => $cdMarca,
                "VRPEACRESCIMO" => $vrPeAcrecimo,
                "NRORG" => $this->environment->getNrOrgTrab(),
                "CDOPERADOR" => $this->environment->getCdOperador()
            );
    	    $query = $this->entityManager->getConnection()->prepare($sql);
            $query->execute($params);
        }
        else {
            $nrProdutoPropCom = $result['NRPRODUTOPROPCOM'];
            
            $sql = "UPDATE PRODUTOPROPCOM
                    SET CDMARCAESCOLHIDA = :CDMARCAESCOLHIDA,
                        VRPEACRESCIMO = :VRPEACRESCIMO,          
                        CDOPERULTATU = :CDOPERADOR,
                        DTULTATU = SYSDATE
                     WHERE NRPRODUTOPROPCOM = :NRPRODUTOPROPCOM";
            $params = array(
                "NRPRODUTOPROPCOM" => $nrProdutoPropCom,
                "CDMARCAESCOLHIDA" => $cdMarca,
                "VRPEACRESCIMO" => $vrPeAcrecimo,
                "CDOPERADOR" => $this->environment->getCdOperador()
            );
    	    $query = $this->entityManager->getConnection()->prepare($sql);
            $query->execute($params);
        }   
    }
    
    public function getComensaisCardapio($nrCardapioTrab){
        
        $sql = "SELECT SUM(QTCOMENSAIS) AS QTTOTCOMENSAIS
                  FROM DIACARDTRAB 
                 WHERE NRCARDAPIOTRAB = :NRCARDAPIOTRAB";
        
        $params = array(
            "NRCARDAPIOTRAB" => $nrCardapioTrab
        );
        
        $query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute($params);
        $result = $query->fetch();
        $comensais = 0;
        if($result)
            $comensais = $result['QTTOTCOMENSAIS'];
        if(!isset($comensais))
            return 0;
        return $comensais;
    }
}